.purdue-home-rtb-hero__slider-wrap .glide__slide{height:300px !important}.purdue-home-rtb-hero-editor.purdue-home-rtb-hero--stack .section .container{margin-left:0 !important;display:flex}.purdue-home-rtb-hero--stack>.image:after{background-color:hsla(0,0%,100%,.9) !important}
