/**
 * #.# Editor Styles
 *
 * CSS for just Backend enqueued after style.scss
 * which makes it higher in priority.
 */

.purdue-home-tabs{
 &__header{
  height:auto;
 }
 &__headers.vertical{
  flex-direction: column;
 }
  
  .pu-blocks-tabs__panel{
    &>.block-editor-inner-blocks{
      padding:0.75rem;
    }
    &.active{
      display:block;
    }
  }
}