.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-color-hero{position:relative;display:flex;flex-direction:column;justify-content:center}@media screen and (min-width: 768px),print{.purdue-color-hero{min-height:700px}}.purdue-color-hero .section.has-padding-bottom-large{height:100%}@media screen and (max-width: 767px){.purdue-color-hero .section.has-padding-bottom-large{padding-bottom:0}}@media screen and (max-width: 767px){.purdue-color-hero .section.has-padding-bottom-large .container{padding-bottom:3rem}}@media screen and (min-width: 768px),print{.purdue-color-hero--body{width:55%;max-width:700px}}.purdue-color-hero--subheader{left:10px;margin-bottom:2.5rem !important}.purdue-color-hero--header{text-align:left !important}@media screen and (min-width: 768px){.purdue-color-hero--header{font-size:4.5rem !important}}@media screen and (min-width: 1024px){.purdue-color-hero--header{font-size:6rem !important}}.purdue-color-hero--subtext{font-size:1rem;font-family:acumin-pro,"Franklin Gothic",sans-serif}@media screen and (min-width: 768px),print{.purdue-color-hero--subtext{font-size:1.25rem;line-height:1.5}}.purdue-color-hero--stats{display:flex;flex-direction:column;justify-content:center;box-shadow:0 0 0 100vmax #000;-webkit-clip-path:inset(0 -100vmax);clip-path:inset(0 -100vmax);height:100%;padding:35px 0}@media screen and (min-width: 768px),print{.purdue-color-hero--stats{padding:0;box-shadow:none;width:42%;position:absolute;right:0;top:0;padding:6.5rem 1.2rem}}@media screen and (min-width: 1024px){.purdue-color-hero--stats{padding:3.25rem}}.purdue-color-hero--stats-heading{font-size:.875rem;line-height:1.5;text-align:left;text-transform:uppercase;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-weight:700;display:flex;align-items:center;color:#cfb991;margin-bottom:40px}@media screen and (min-width: 768px),print{.purdue-color-hero--stats-heading{margin-bottom:51px !important}}.purdue-color-hero--stats-heading::after{content:"";flex-grow:1;border-top:2px solid #cfb991;width:84px;position:relative;display:flex;margin-left:25px}.purdue-color-hero--stats-wrapper{display:flex;justify-content:space-between;width:100%}@media screen and (min-width: 768px),print{.purdue-color-hero--stats-wrapper{justify-content:auto;flex-direction:column}}.purdue-color-hero--stats-wrapper--box{width:50%}@media screen and (min-width: 768px),print{.purdue-color-hero--stats-wrapper--box{width:100%}}.purdue-color-hero--stats-wrapper--box:nth-child(1){margin-bottom:75px}@media screen and (max-width: 767px){.purdue-color-hero--stats-wrapper--box:nth-child(1){margin-bottom:1rem;padding-right:2rem}}.purdue-color-hero--stats-wrapper--box--stat{font-size:3rem;line-height:.9;font-weight:bold;color:#cfb991;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";text-transform:uppercase;display:block}@media screen and (min-width: 768px),print{.purdue-color-hero--stats-wrapper--box--stat{font-size:5rem;line-height:1}}@media screen and (min-width: 1024px){.purdue-color-hero--stats-wrapper--box--stat{font-size:6rem;line-height:1}}@media screen and (min-width: 1216px){.purdue-color-hero--stats-wrapper--box--stat{font-size:126px;line-height:.9}}@media screen and (min-width: 1408px){.purdue-color-hero--stats-wrapper--box--stat{font-size:136px;line-height:.9}}.purdue-color-hero--stats-wrapper--box--description,.purdue-color-hero--stats-wrapper--box--source{font-size:.875rem;line-height:1.5;font-family:acumin-pro,"Franklin Gothic",sans-serif;display:block}@media screen and (min-width: 768px),print{.purdue-color-hero--stats-wrapper--box--description,.purdue-color-hero--stats-wrapper--box--source{font-size:1.875rem;line-height:1.3}}.purdue-color-hero--stats-wrapper--box--source{font-style:italic;text-transform:capitalize;display:block}.purdue-color-hero--stats-wrapper--box--description{font-weight:600;margin-top:10px}.purdue-color-hero--stats-wrapper--box--source{font-weight:400;margin-top:1rem}.purdue-color-hero--stats-wrapper--box--source a{color:#fff !important}.purdue-color-hero--stats-wrapper--box--source a:hover{color:#fff !important}.purdue-color-hero ul.purdue-home-button-list{list-style-type:none;padding:0;justify-content:flex-start;margin-top:2rem}.purdue-color-hero ul.purdue-home-button-list li:first-child{padding-left:0}
