!function(){var i;i=jQuery,wp.customize("my_footer_image",function(o){o.bind(function(o){i(".footer-image").text(o)})}),wp.customize.bind("ready",function(){"wordpress"!==i('input[name="_customize-radio-search_option_radio"]:checked').val()?(i("#customize-control-quick_link_1_text").hide(),i("#customize-control-quick_link_2_text").hide(),i("#customize-control-quick_link_3_text").hide(),i("#customize-control-quick_link_4_text").hide(),i("#customize-control-quick_link_5_text").hide(),i("#customize-control-quick_link_1_link").hide(),i("#customize-control-quick_link_2_link").hide(),i("#customize-control-quick_link_3_link").hide(),i("#customize-control-quick_link_4_link").hide(),i("#customize-control-quick_link_5_link").hide(),i("#customize-control-google-search-id").show()):(i("#customize-control-google-search-id").hide(),i("#customize-control-quick_link_1_text").show(),i("#customize-control-quick_link_2_text").show(),i("#customize-control-quick_link_3_text").show(),i("#customize-control-quick_link_4_text").show(),i("#customize-control-quick_link_5_text").show(),i("#customize-control-quick_link_1_link").show(),i("#customize-control-quick_link_2_link").show(),i("#customize-control-quick_link_3_link").show(),i("#customize-control-quick_link_4_link").show(),i("#customize-control-quick_link_5_link").show()),i(document).on("click",'input[name="_customize-radio-search_option_radio"]',function(){"wordpress"!==i(this).val()?(i("#customize-control-google-search-id").show(),i("#customize-control-quick_link_1_text").hide(),i("#customize-control-quick_link_2_text").hide(),i("#customize-control-quick_link_3_text").hide(),i("#customize-control-quick_link_4_text").hide(),i("#customize-control-quick_link_5_text").hide(),i("#customize-control-quick_link_1_link").hide(),i("#customize-control-quick_link_2_link").hide(),i("#customize-control-quick_link_3_link").hide(),i("#customize-control-quick_link_4_link").hide(),i("#customize-control-quick_link_5_link").hide()):(i("#customize-control-google-search-id").hide(),i("#customize-control-quick_link_1_text").show(),i("#customize-control-quick_link_2_text").show(),i("#customize-control-quick_link_3_text").show(),i("#customize-control-quick_link_4_text").show(),i("#customize-control-quick_link_5_text").show(),i("#customize-control-quick_link_1_link").show(),i("#customize-control-quick_link_2_link").show(),i("#customize-control-quick_link_3_link").show(),i("#customize-control-quick_link_4_link").show(),i("#customize-control-quick_link_5_link").show())})})}();