!function(){"use strict";const e=document.querySelectorAll(".purdue-home-canopy-hero"),t=window.innerHeight-80;window.innerWidth;var a=document.querySelector(":root");e&&e.length>0&&e.forEach(e=>{const t=e.querySelectorAll(".continuous-moving-slider");if(t&&t.length>0){if(t[0]){const e=t[0].querySelectorAll(".slide"),l=e.length/2*-284+"px",s=5*e.length;a.style.setProperty("--animationSpeed1",s),a.style.setProperty("--translate1",l)}if(t[1]){const e=t[1].querySelectorAll(".slide"),l=e.length/2*-284+"px",s=5*e.length;a.style.setProperty("--animationSpeed2",s),a.style.setProperty("--translate2",l)}}const l=e.querySelector(".cta-btnctrl");l.addEventListener("click",()=>{l.classList.contains("cta-play")?t.forEach((e,t)=>{e.querySelector(".slide-track").style.animationPlayState="running"}):t.forEach(e=>{e.querySelector(".slide-track").style.animationPlayState="paused"}),function(e,t=null){if(!e)return;const a=e.querySelector("i"),l=e.classList.contains("cta-play"),s=e.classList.contains("cta-pause"),c=null===t?l:!0===t,r=e.getAttribute("aria-label"),o=e.dataset.toggleLabel;(null===t||c&&l||!c&&s)&&(e.setAttribute("aria-label",o),e.dataset.toggleLabel=r),c?(e.classList.remove("cta-play"),e.classList.add("cta-pause"),a?.classList.add("fa-circle-pause","cta-pause-icon"),a?.classList.remove("fa-circle-play","cta-play-icon")):(e.classList.add("cta-play"),e.classList.remove("cta-pause"),a?.classList.add("fa-circle-play","cta-play-icon"),a?.classList.remove("fa-circle-pause","cta-pause-icon"))}(l)})});const l=document.querySelectorAll(".hero-down-arrow");l&&l.length>0&&l.forEach(e=>{e.addEventListener("click",()=>{window.scroll({top:t,behavior:"smooth"})})})}();