@import "../../../node_modules/bulma/bulma.sass";

 .continuous-moving-slider-editor {
	background: white;
	margin: auto;
	position: relative;
	width: 100%;
	&:not(:last-child){
	 margin-bottom:0.75rem;
	}
	.slide-track {
	  display: flex;
	  width: auto;
	}
	&.row-2{
	  .slide-track {
		position:relative;
		left:-125px;
	  }
	}
	.slide {
	 height: 153px;
	 width: 276px;
	 border-radius: 2px;
	 box-shadow: 2px 4px 5px -1px rgba(0,0,0,0.3);
	 flex: 0 0 auto;
	 position:relative;
	 margin:0 0.5rem;
	 &>*{
	   max-width: 100%;
	   object-fit: cover;
	   position: absolute;
	   width: 100%;
	   height: 100%;
	   top: 0;
	   left: 0;
	   min-height: 0;
	   object-position: center;
	 }
	}
  }
  .purdue-home-canopy-hero{
	h1{
		margin-top:0;
		font-size:5.75rem !important;
	}
	@include widescreen  {
	  @media (min-height: 900px) {
		height:auto;
	  }
  
	}
}