// Skip link - visible on keyboard focus, hidden otherwise via is-sr-only
.skip-link:focus {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1001;
  background: #000;
  color: #fff;
  padding: 0.5em 1em;
  display: inline-block;
  clip: auto !important;
  clip-path: none;
  width: auto !important;
  height: auto !important;
  overflow: visible !important;
  white-space: normal !important;
}

$thetransition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
@keyframes fadeOutHeader {
  0% {
    transform: translateY(0);
  }
  100% {
    transform: translateY(-100%);
  }
}
@keyframes fadeInHeader {
  0% {
    transform: translateY(-100%);
  }
  100% {
    transform: translateY(0);
  }
}
.no-scroll-page {
  overflow: hidden;
}
.no-scroll {
  overflow: hidden;
  top: 0;
  &.has-global-header {
    overflow: auto;
    @include until-widescreen {
      overflow: hidden;
    }
  }
}
.header--global {
  position: sticky;
  z-index: 1001;
  &.header--two-rows {
    z-index: 1000;
  }
  &.is-fixed-top {
    &:not(.second-nav-sticky) {
      .purdue-top-nav {
        left: 0;
        position: fixed;
        right: 0;
      }
    }
    &.second-nav-sticky {
      left: 0;
      position: fixed;
      right: 0;
    }
  }
}
.navbar-menu {
  .menu-items {
    flex-wrap: wrap;
    .navbar-dropdown {
      border-bottom-left-radius: 4px;
      border-bottom-right-radius: 4px;
      transform-style: preserve-3d;
      @include tablet {
        top: 100%;
      }
    }
    .navbar-item {
      &.active {
        & > a:before {
          visibility: visible;
          transform: scaleX(1);
        }
      }
      &:hover {
        .navbar-link {
          &:after {
            border: none;
            transform: rotate(-180deg);
          }
        }
        &.active {
          & > a {
            &:before {
              visibility: visible;
              transform: scaleX(1);
            }
          }
        }
        & > a.is-active-page {
          &:before {
            visibility: visible;
            transform: scaleX(1);
          }
        }
      }
      .submenu {
        transform-style: preserve-3d;
        &:hover {
          & > .navbar-dropdown-submenu {
            display: block;
          }
          .navbar-link-submenu {
            &:after {
              border: none;
              right: -1.6rem;
            }
          }
        }
        .navbar-dropdown-submenu {
          top: -0.6rem;
          margin-left: 100%;
          background-color: #fff;
          box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1);
          display: none;
          left: 0;
          min-width: 12rem;
          padding: 0.5rem 0;
          position: absolute;
          z-index: 20;
          border-radius: 4px;
          transform: translateZ(-10px);
        }
        .navbar-link-submenu {
          margin-right: 1.5rem;
          &:after {
            content: "";
            background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='12' height='7' viewBox='0 0 12 7' fill='none'%3E%3Cpath d='M1 1L6 6L11 1' stroke='black' stroke-width='2' stroke-linecap='round'/%3E%3C/svg%3E");
            pointer-events: none;
            background-repeat: no-repeat;
            position: absolute;
            top: calc(50% - 2.5px);
            right: -1.125rem;
            width: 12px;
            height: 7px;
            transform: rotate(-90deg);
            transition: right 0.3s ease;
          }
        }
      }
    }
    a {
      position: relative;
      font-weight: 600;
      text-decoration: none;
      color: $black;
      &:before {
        content: "";
        height: 3px;
        width: 100%;
        position: absolute;
        display: block;
        bottom: 0;
        left: 0;
        visibility: hidden;
        background: $aged-gold;
        transform: scaleX(0);
        transition: $thetransition;
      }
      &.navbar-link {
        &:after {
          content: "";
          background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='12' height='7' viewBox='0 0 12 7' fill='none'%3E%3Cpath d='M1 1L6 6L11 1' stroke='black' stroke-width='2' stroke-linecap='round'/%3E%3C/svg%3E");
          pointer-events: none;
          background-repeat: no-repeat;
          position: absolute;
          top: 2.2rem;
          right: 1.125rem;
          width: 12px;
          height: 7px;
          border: none;
          transform: rotate(0);
          transition: transform 0.3s ease;
        }
      }
      &.is-active-page {
        &:before {
          visibility: visible;
          transform: scaleX(1);
        }
      }
      &:hover {
        &:before {
          visibility: visible;
          transform: scaleX(1);
        }
      }
    }
  }
}
.navbar.purdue-top-nav {
  padding: 1.22rem 3.25rem;
  align-items: center;
  font-family: $acumin-pro;
  margin: 0 auto;
  font-size: 1rem;
  font-weight: 600;
  color: $black;
  background: $white;
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.2);
  z-index: 100;
  a {
    color: $black;
  }
  @include touch {
    padding: 1.25rem $side-padding-tablet;
  }
  @include mobile {
    padding: 1.25rem $side-padding-mobile;
  }
  .icon {
    background: none;
    border: none;
    width: 4em;
    &:hover {
      cursor: pointer;
    }
    .burger-icon {
      display: block;
      font-size: 2em;
      width: 2.5em;
    }
  }
  .navbar-brand {
    @include until-widescreen {
      width: 100%;
    }
    @include touch {
      min-height: 2rem;
    }
    .navbar-item {
      padding: 0;
      margin: 0;
      img {
        width: 223px;
        max-height: 40.45px;
        @include widescreen-only {
          max-height: 33px;
          width: 181.89px;
        }
        @include touch {
          max-height: 33px;
          width: 181.89px;
        }
      }
    }
    .icon {
      width: 3em;
      font-weight: 600;
      .burger-icon {
        width: 1.5em;
        &.is-hidden {
          display: none;
        }
        &.is-active {
          display: block;
        }
      }
      span {
        top: 0;
        left: 0;
        position: relative;
        background: none;
        height: auto;
        width: auto;
        transform: none;
      }
      @include until-widescreen {
        display: flex;
        width: auto;
      }

      .close-icon {
        &.is-hidden {
          display: none;
        }
        &.is-active {
          display: flex;
        }
        font-size: 2.2em;
        width: 1.75rem;
      }
    }
  }
  .navbar-menu {
    @include until-widescreen {
      display: none;
    }
    .menu-items {
      @include tablet {
        margin-top: -1.22rem;
        margin-bottom: -1.22rem;
      }
    }
    a {
      &.navbar-link {
        &:before {
          bottom: 1.95rem;
          left: 12px;
          width: calc(100% - 52px);
        }
        &:after {
          top: 2.9rem;
        }
      }
    }
  }
}
.purdue-top-nav__second-row {
  &.navbar-menu {
    background: $primary-background-gray;
    min-height: 4rem;
    padding: 0 3.25rem;
    z-index: 999;
    box-shadow: 0 0 2px rgba(0, 0, 0, 0.2);
    @include until-widescreen {
      display: none;
    }
    .menu-items {
      margin: 0 -0.75rem;
      flex: 1;
      .purdue-header-cta-button-wrap {
        margin-left: auto;
        &:hover {
          a {
            background-color: $black;
          }
        }
        a {
          color: $white;
          font-weight: 900;
          &:hover {
            color: $black;
          }
          &::before {
            visibility: hidden;
          }
        }
      }
    }
    a {
      &.navbar-link {
        &:before {
          bottom: 1.25rem;
          left: 12px;
          width: calc(100% - 52px);
        }
        &:hover,
        &.active,
        &:focus,
        &:focus-within {
          background: $primary-background-gray;
        }
      }
    }
    .navbar-dropdown {
      background: $primary-background-gray;
    }
    .navbar-item {
      &:hover {
        & > a {
          background: $primary-background-gray;
        }
      }
      .submenu {
        .navbar-dropdown-submenu {
          background: $primary-background-gray;
        }
      }
    }
  }
}
.header--global.header--two-rows {
  .navbar.purdue-top-nav {
    z-index: 1000;
  }
  .navbar-brand {
    width: 100%;
    justify-content: space-between;
    align-items: center;
    .navbar-logo {
      display: flex;
      align-items: stretch;
      @include mobile {
        flex-direction: column;
        width: 100%;
        justify-content: flex-start;
        align-items: flex-start;
      }
      a {
        text-decoration: none;
      }
      .navbar-item {
        padding-right: 1.25rem;
        border-right: 1px solid $steel-gray;
        @include mobile {
          padding-right: 0;
          border-right: none;
          padding-bottom: 1.25rem;
          border-bottom: 1px solid $steel-gray;
          width: 100%;
        }
      }
      .navbar-site-name {
        font-family: $acumin-pro-condensed;
        font-size: 1.5625rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1;
        letter-spacing: -0.03125rem;
        padding-left: 1.25rem;
        max-width: 25rem;
        padding-bottom: 0.2rem;
        display: flex;
        align-items: center;
        @include mobile {
          padding-left: 0;
          padding-top: 1.25rem;
          max-width: 100%;
        }
      }
    }
  }
  .navbar-burger {
    @include desktop {
      display: block;
      &.is-hidden {
        display: none;
      }
      &.is-active {
        display: block;
      }
    }
  }
  .navbar-buttons {
    .navbar-close {
      &.is-hidden {
        display: none;
      }
      &.is-active {
        display: flex;
      }
    }

    .purdue-home-button{
      margin-right: 3rem;
        color: #fff;   
        &:hover{
          color: #000;
        }   
    }
   
    @include mobile {
      position: absolute;
      right: 1.25rem;
      top: 0.8rem;
    }
  }
  .navbar-start > .navbar-item {
    @include widescreen {
      height: 64px;
    }
  }
}
.navbar-find-info {
  display: flex;
  flex-direction: row;
  justify-content: center;
  left: 0;
  top: 0;
  z-index: 1003;
  background-color: rgba(0, 0, 0);
  animation: fadeOutHeader 0.3s linear;
  width: 100%;
  height: 100%;
  position: fixed;
  padding: 5rem;
  overflow-y: auto;
  color: white;
  font-family: $acumin-pro;
  transform: translateY(-100%);
  @include touch {
    padding: 3rem $side-padding-tablet;
  }
  @include mobile {
    padding: 3rem $side-padding-mobile;
  }
  &.is-hidden {
    display: none;
  }
  &.is-active {
    animation: fadeInHeader 0.3s linear;
    transform: translateY(0);
  }
  .icon {
    background: none;
    border: none;
    width: 7rem;
    color: $white;
    position: absolute;
    top: 4rem;
    right: 8rem;
    font-size: 1.25rem;
    font-family: $united-sans;
    &:hover {
      cursor: pointer;
    }
    .close-icon {
      display: block;
      width: 2rem;
      margin-left: 0.5rem;
      @include mobile {
        font-size: 3rem;
      }
    }
    @include until-widescreen {
      top: 4rem;
      right: 4rem;
      font-size: 1rem;
    }
    @include mobile {
      top: 2.5rem;
      right: 1rem;
      font-size: 1rem;
    }
  }
  &__items {
    background: none;
    min-height: 100%;
    width: 1000px;
    max-width: 100%;
    @include touch {
      width: 100%;
      min-width: 0;
      padding: 2rem $side-padding-tablet 2rem;
      box-shadow: $box-shadow;
    }
    @include mobile {
      padding: 0;
    }
    .nav-brand {
      padding-bottom: 3rem;
      text-align: center;
      @include touch {
        padding-bottom: 2rem;
        text-align: left;
      }
      img {
        max-height: 45px;
        @include touch {
          max-height: 33px;
          max-width: 182px;
        }
      }
    }

    .columns {
      justify-content: space-between;
      @include mobile {
        padding: 0 1rem;
      }
    }
    .menu-items {
      button {
        border: none;
        background: none;
        padding: 0;
      }
      a,
      button {
        color: $white;
        font-size: 1.875rem;
        font-weight: 600;
        position: relative;
        margin-bottom: 0.5rem;
        display: inline-block;
        text-decoration: none;
        &:before {
          content: "";
          height: 3px;
          width: 100%;
          position: absolute;
          display: block;
          bottom: -2px;
          left: 0;
          visibility: hidden;
          background: $boiler-gold;
          transform: scaleX(0);
          transition: $thetransition;
        }
        &:hover {
          &:before {
            visibility: visible;
            transform: scaleX(1);
          }
        }
        &.is-active-page:before {
          visibility: visible;
          transform: scaleX(1);
        }
        @include mobile {
          font-size: 1.5rem;
        }
      }
      .navbar-item {
        color: $white;
        background: none !important;
        padding: 0;
        display: block;
        &:hover {
          background: none !important;
          .navbar-link,
          .navbar-dropdown {
            background: none !important;
          }
        }
      }
      .navbar-link {
        color: $white;
        padding: 0;
        display: inline;
        &:after {
          content: none;
        }
        &:hover {
          background: none;
        }
      }
      .navbar-dropdown {
        background: none !important;
        position: relative;
        display: block;
        border: none;
        padding-left: 1rem;
        box-shadow: none;
        a,
        button {
          font-size: 1.125rem;
          font-weight: 500;
          @include mobile {
            font-size: 1rem;
          }
        }
      }
      .navbar-dropdown-submenu {
        padding-left: 1rem;
        box-shadow: none;
      }
    }
    .navbar-other-links-wrapper {
      padding: 1rem 0 5rem;
      @include touch {
        padding: 1rem 0 3rem;
      }
      @include mobile {
        padding: 0 1rem 3rem;
      }
    }
    .navbar-links-description {
      font-family: $united-sans-condensed;
      font-size: 1rem;
      text-transform: uppercase;
      font-weight: 900;
      letter-spacing: 2.3px;
      display: block;
      border-bottom: 2px solid $white;
      padding-bottom: 1rem;
      @include mobile {
        padding-top: 1rem;
      }
    }
    .navbar-other-links {
      display: flex;
      flex-wrap: wrap;
      a {
        color: $white;
        font-size: 1.125rem;
        font-weight: 600;
        position: relative;
        display: inline-block;
        text-decoration: none;
        &:before {
          content: "";
          height: 3px;
          width: 100%;
          position: absolute;
          display: block;
          bottom: -2px;
          left: 0;
          visibility: hidden;
          background: $boiler-gold;
          transform: scaleX(0);
          transition: $thetransition;
        }
        &:after {
          content: "";
          background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23cfb991' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
          top: 3px;
          margin-left: 0.75rem;
          height: 1.25rem;
          width: 1.125rem;
          background-repeat: no-repeat;
          background-size: cover;
          transition: transform 0.3s ease;
          display: inline-block;
          position: absolute;
        }
        &:hover {
          &:before {
            visibility: visible;
            transform: scaleX(1);
          }
          &:after {
            transform: translateX(3px);
          }
        }
      }
      .menu-item {
        display: flex;
        align-items: center;
        padding-top: 1rem;
        margin-right: 2rem;
        padding-right: 2rem;
      }
    }
    .navbar-quick-links {
      padding-top: 1rem;
      .menu-item {
        margin-bottom: 0.75rem;
      }
      a {
        display: inline-block;
        width: 100%;
        border-radius: 4px;
        background-color: $boiler-gold;
        box-shadow: 0 1px 2px 0 rgba(142, 111, 62, 0.3);
        padding: 0.5rem 1.5rem;
        font-family: $united-sans-condensed;
        font-size: 1.125rem;
        text-transform: uppercase;
        font-weight: 900;
        letter-spacing: 0.5px;
        color: $black;
        display: flex;
        justify-content: space-between;
        align-items: center;
        border: 1px solid $boiler-gold;
        text-decoration: none;

        &:after {
          content: "";
          background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23000000' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
          right: -0.25rem;
          margin-left: 0.75rem;
          height: 1.25rem;
          width: 1.125rem;
          background-repeat: no-repeat;
          background-size: cover;
          transition: transform 0.3s ease;
        }
        &:hover {
          background: $black;
          color: $white;
          &:after {
            background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23cfb991' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
            transform: translateX(3px);
          }
        }
        @include mobile {
          padding: 0.5rem 1rem;
          font-size: 1rem;
        }
      }
    }
    .search-box {
      width: 100%;
      &:not(:last-child) {
        margin-bottom: 3rem;
      }
      @include touch {
        &:not(:last-child) {
          margin-bottom: 1.25rem;
        }
      }
    }
  }
  .accordion__heading {
    cursor: pointer;
    &:after {
      content: "";
      background-image: url("data:image/svg+xml,%3C%3Fxml version='1.0' encoding='UTF-8'%3F%3E%3Csvg width='73.5391052px' height='73.5391052px' viewBox='0 0 73.5391052 73.5391052' version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'%3E%3Ctitle%3Eclose_icon_circle%3C/title%3E%3Cg stroke='none' stroke-width='1' fill='none' fill-rule='evenodd'%3E%3Cg transform='translate(36.7696, 36.7696) rotate(-315) translate(-36.7696, -36.7696)translate(10.7696, 10.7696)' stroke='%23cfb991' stroke-width='4'%3E%3Ccircle cx='26' cy='26' r='24'%3E%3C/circle%3E%3Cline x1='26.5' y1='14' x2='26.5' y2='38' stroke-linecap='round' stroke-linejoin='round'%3E%3C/line%3E%3Cline x1='25.6896552' y1='14.5116279' x2='25.6896552' y2='38.6976744' stroke-linecap='round' stroke-linejoin='round' transform='translate(25.6897, 26.6047) rotate(-90) translate(-25.6897, -26.6047)'%3E%3C/line%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
      transition: all 0.3s ease;
      width: 2.4rem;
      height: 2.4rem;
      display: block;
      position: absolute;
      top: calc(50% - 1.1rem);
      right: -3rem;
      background-size: cover;
      margin-left: 1rem;
      transform: rotate(-45deg);
    }
    &.is-open {
      &:after {
        content: "";
        transform: rotate(0);
      }
    }
  }

  .navbar-dropdown {
    .accordion__heading {
      &:after {
        content: "";
        width: 1.8rem;
        height: 1.8rem;
        top: calc(50% - 0.9rem);
        right: -2rem;
      }
    }
    &.hide {
      display: none !important;
    }
    &.show {
      display: block !important;
    }
  }
  &.is-global {
    @include widescreen {
      top: 91.03px;
      .navbar-find-info__menu {
        display: none;
      }
      .nav-brand,
      .navbar-close {
        display: none;
      }
      z-index: 999;
      height: auto;
      position: absolute;
    }
    padding-top: 6rem;
    @include mobile {
      padding-top: 5rem;
    }
    .icon {
      top: 3rem;
      right: 6rem;
      @include touch {
        right: 3rem;
      }
      @include mobile {
        top: 2rem;
        right: 1rem;
      }
    }
    .navbar-find-info__items {
      display: grid;
      grid-template-columns: 1fr auto;
      grid-template-rows: auto auto;
      width: 100%;
      max-width: 1344px;
      column-gap: 50px;
      @include until-widescreen {
        grid-template-rows: auto auto auto auto;
        row-gap: 24px;
      }
      @include mobile {
        display: block;
      }
      .nav-brand {
        font-family: $acumin-pro-condensed;
        font-weight: 700;
        line-height: 1.06;
        letter-spacing: -0.0375rem;

        @include until-widescreen {
          grid-column: 1/3;
          grid-row: 1/2;
          font-size: 3rem;
          padding-bottom: 1rem;
        }
        @include mobile {
          font-size: 1.875rem;
          padding-bottom: 2rem;
        }
      }
      .search-box {
        grid-column: 1/2;
        grid-row: 1/2;
        @include until-widescreen {
          grid-column: 1/3;
          grid-row: 2/3;
          margin-bottom: 1.25rem;
        }
      }
      .navbar-find-info__menu {
        @include until-widescreen {
          grid-column: 1/2;
          grid-row: 3/4;
        }
        @include mobile {
          padding: 1rem 0 0;
        }
      }
      .navbar-find-info__quicklinks {
        grid-column: 2/3;
        grid-row: 1/3;
        @include until-widescreen {
          grid-column: 2/3;
          grid-row: 3/4;
        }
        @include mobile {
          padding: 1rem 0 3rem;
        }
      }
      .navbar-other-links-wrapper {
        grid-column: 1/2;
        grid-row: 2/3;
        @include until-widescreen {
          grid-column: 1/3;
          grid-row: 4/5;
        }
        @include mobile {
          padding: 1rem 0 0;
        }
      }
      .menu-items {
        .purdue-header-cta-button-wrap {
          margin-top: 1rem;
          a.purdue-home-button {
            font-size: 1rem;
            display: inline-flex;
          }
          &:hover {
            a {
              &::before {
                visibility: hidden;
              }
            }
          }
        }
      }
    }
  }
}

.purdue-second-nav {
  padding: 0 1.25rem;
  border-bottom: 1px solid $boiler-gold;
  min-height: 0;
  display: flex;
  justify-content: center;
  @include touch {
    display: block;
    padding: 0;
  }
  &.is-large-menu{
    display: flex;
    @media screen and (max-width: 1216px) {
     display: none;
    }
  }
  &.is-large-menu-mobile {
    @media screen and (max-width: 1216px) {
      display: block;
      padding: 0;
    }
  }
  .menu-title{
    background: none;
    padding: 1rem 1.5rem 1rem;
    color: #fff;
    font-family: "United Sans Condensed", Impact, "Arial Black", "sans serif";
    font-size: 1rem;
    font-weight: 900;
    letter-spacing: 2px;
    line-height: 1.5;
    text-transform: uppercase;
    position: relative;
    margin: 0;
  }
  &.second-nav-sticky.is-fixed-top {
    left: 0;
    position: fixed;
    right: 0;
  }
  &.is-large-menu-mobile{
    & > .accordion__heading{
      @media screen and (max-width: 1216px) {
        display: flex;
        width: 100%;
      }
    }
     .menu-items {
      @media screen and (max-width: 1216px) {
        display: none;
        flex-direction: column;
        justify-content: flex-start;
        overflow: hidden;
        padding: 0.75rem;
        background: $black;
        position: absolute;
      }
    }
  }
  & > .accordion__heading {
    display: none;
    @include touch {
      display: flex;
      width: 100%;
    }
    background: none;
    width: auto;
    padding: 1.25rem;
    color: $white;
    font-family: $united-sans-condensed;
    font-size: 1rem;
    font-weight: 900;
    letter-spacing: 2px;
    line-height: 1.5;
    text-transform: uppercase;
    position: relative;
    border: none;
    border-bottom: 1px solid $black;
    &:after {
      content: "";
      position: absolute;
      top: calc(50% - 6px);
      right: -1rem;
      width: 18px;
      height: 12px;
      transition: transform 0.3s ease;
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='18' height='14' viewBox='0 0 12 7' fill='none'%3E%3Cpath d='M1 1L6 6L11 1' stroke='%23ffffff' stroke-width='2' stroke-linecap='round'/%3E%3C/svg%3E");
    }
  }
  .accordion__heading[aria-expanded="true"] {
    border-bottom: 1px solid $white;
    &:after {
      transform: rotate(-180deg);
    }
  }
  .menu-items {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    width: auto;
    color: $white;
    transition: all 0.2s ease;
    @include touch {
      display: none;
      flex-direction: column;
      justify-content: flex-start;
      overflow: hidden;
      padding: 0.75rem;
      background: $black;
      position: absolute;
    }
    &.show {
      display: block;
      width: 100%;
    }
    &.hide {
      opacity: 0;
    }
    .navbar-link {
      padding-top: 1rem;
      padding-bottom: 1rem;
    }
    .navbar-item {
      &:not(.has-dropdown, .submenu) {
        @include desktop {
          padding: 1rem 0.75rem;
        }
      }
      button.accordion__heading {
        background: none;
        border: none;
        cursor: pointer;
        color: $white;
        padding: 0.5rem 0.75rem;
        &:before {
          bottom: 9px;
          left: 11px;
          width: calc(100% - 24px);
        }
      }
      &:hover {
        a {
          background: none;
        }
        .navbar-link {
          &:after {
            transform: rotate(-180deg);
          }
        }
      }
      &.submenu {
        &:hover {
          a {
            background: none;
          }
          .navbar-link-submenu {
            &:after {
              right: -1.6rem;
            }
          }
        }
        @include touch {
          &:hover {
            .navbar-link-submenu {
              &:after {
                right: -1.125rem;
              }
            }
          }
        }
      }
      @include touch {
        &:hover {
          .navbar-link {
            &:after {
              transform: none;
            }
          }
        }
      }
      a,
      button {
        color: $white;
        font-family: $united-sans-condensed;
        font-size: 0.875rem;
        font-weight: 900;
        letter-spacing: 2px;
        line-height: 1.5;
        text-transform: uppercase;
        position: relative;
        text-decoration: none;
        &:after {
          border-color: $white;
        }
        &:before {
          content: "";
          height: 2px;
          width: 100%;
          position: absolute;
          display: block;
          bottom: 0;
          left: -1px;
          visibility: hidden;
          background: $boiler-gold;
          transform: scaleX(0);
          transition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
          @include touch {
            bottom: -2px;
          }
        }
        &:hover {
          &:before {
            transform: scaleX(100%);
            visibility: visible;
          }
        }
        &.navbar-link {
          &:after {
            content: "";
            background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='12' height='7' viewBox='0 0 12 7' fill='none'%3E%3Cpath d='M1 1L6 6L11 1' stroke='%23ffffff' stroke-width='2' stroke-linecap='round'/%3E%3C/svg%3E");
            background-repeat: no-repeat;
            position: absolute;
            top: calc(50% + 1px);
            right: 1.125rem;
            width: 12px;
            height: 7px;
            border: none;
            transform: rotate(0);
            transition: transform 0.3s ease;
          }
          @include touch {
            display: inline-block;
            &:after {
              top: 1.2rem;
            }
          }
          &:hover {
            background: none;
          }
          &:before {
            bottom: 1rem;
            width: calc(100% - 47px);
            left: 11px;
            @include touch {
              bottom: 9px;
            }
          }
        }
        &.is-active-page {
          &:before {
            visibility: visible;
            transform: scaleX(1);
          }
        }
      }
    }

    .navbar-dropdown {
      background-color: $black;
      @include touch {
        padding: 0;
      }
    }
    .navbar-link-submenu {
      margin-right: 1.5rem;
      &:after {
        content: "";
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='12' height='7' viewBox='0 0 12 7' fill='none'%3E%3Cpath d='M1 1L6 6L11 1' stroke='%23ffffff' stroke-width='2' stroke-linecap='round'/%3E%3C/svg%3E");
        background-repeat: no-repeat;
        position: absolute;
        top: calc(50% - 3.5px);
        right: -1.125rem;
        width: 12px;
        height: 7px;
        transform: rotate(-90deg);
        transition: right 0.3s ease;
      }

      @include touch {
        &:after {
          transform: rotate(0deg);
        }
      }
    }
    .submenu {
      &:hover {
        & > .navbar-dropdown-submenu {
          display: block;
        }
      }
      .navbar-dropdown-submenu {
        top: -0.6rem;
        margin-left: 100%;
        background-color: $black;
        box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1);
        display: none;
        left: 0;
        min-width: 12rem;
        padding: 0.5rem 0;
        position: absolute;
        z-index: 20;
        border-radius: 4px;
        @include touch {
          position: relative;
          display: block;
          top: 0;
          margin-left: 0;
          &.hide {
            display: none;
          }
          &.show {
            display: block;
          }
        }
      }
    }
    .accordion__heading {
      cursor: pointer;
      &:after {
        content: "";
        background-image: url("data:image/svg+xml,%3C%3Fxml version='1.0' encoding='UTF-8'%3F%3E%3Csvg width='73.5391052px' height='73.5391052px' viewBox='0 0 73.5391052 73.5391052' version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'%3E%3Ctitle%3Eclose_icon_circle%3C/title%3E%3Cg stroke='none' stroke-width='1' fill='none' fill-rule='evenodd'%3E%3Cg transform='translate(36.7696, 36.7696) rotate(-315) translate(-36.7696, -36.7696)translate(10.7696, 10.7696)' stroke='%23cfb991' stroke-width='4'%3E%3Ccircle cx='26' cy='26' r='24'%3E%3C/circle%3E%3Cline x1='26.5' y1='14' x2='26.5' y2='38' stroke-linecap='round' stroke-linejoin='round'%3E%3C/line%3E%3Cline x1='25.6896552' y1='14.5116279' x2='25.6896552' y2='38.6976744' stroke-linecap='round' stroke-linejoin='round' transform='translate(25.6897, 26.6047) rotate(-90) translate(-25.6897, -26.6047)'%3E%3C/line%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
        transition: all 0.3s ease;
        width: 1.6rem;
        height: 1.6rem;
        display: block;
        position: absolute;
        top: calc(50% - 0.85rem);
        right: -1.5rem;
        background-size: cover;
        margin-left: 1rem;
        transform: rotate(-45deg);
      }
      &.is-open {
        &:after {
          content: "";
          transform: rotate(0);
        }
      }
    }
  }
}
