.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-50-50-animated-header-animate.pause *{animation-play-state:paused}@keyframes slideIn{0%{transform:translateX(-100%);opacity:0}100%{transform:translateX(0);opacity:1}}@keyframes slideOut{0%{opacity:1;transform:translateX(0)}100%{opacity:0;transform:translateX(100%)}}.purdue-home-50-50-animated-header .column{flex-direction:column;display:flex;justify-content:center}.purdue-home-50-50-animated-header .column:first-child{z-index:20;background:#fff}.purdue-home-50-50-animated-header .column:last-child{align-items:center}.purdue-home-50-50-animated-header .controls{display:flex;width:100%;justify-content:flex-end;align-content:flex-end;flex-grow:1;flex-wrap:wrap}.purdue-home-50-50-animated-header .cta-btnctrl{color:#8e6f3e;font-size:2rem;z-index:2;background:none;border:none;cursor:pointer;padding:0;line-height:1}.purdue-home-50-50-animated-header h2.second-level-page-heading{font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-size:4.75rem;font-weight:700;letter-spacing:0;line-height:.9;text-align:center;max-width:1061px;margin-top:0;margin-bottom:0;text-transform:uppercase}@media screen and (max-width: 1023px){.purdue-home-50-50-animated-header h2.second-level-page-heading{font-size:3.375rem;margin-bottom:1.875rem}}@media screen and (max-width: 767px){.purdue-home-50-50-animated-header h2.second-level-page-heading{font-size:3.375rem}}.purdue-home-50-50-animated-header .purdue-home-cta-hero__header-static{position:relative;z-index:1;background:#fff;display:block;width:100%}.purdue-home-50-50-animated-header .purdue-home-cta-hero__header-animate{display:block}.purdue-home-50-50-animated-header .purdue-home-cta-hero__header-animate-item{opacity:0;position:relative;z-index:0;transform:translateX(-100%)}.purdue-home-50-50-animated-header .purdue-home-cta-hero__header-animate-item.slide-in{display:inline-block;transform:translateY(0);opacity:1;animation:slideIn 2s}.purdue-home-50-50-animated-header .purdue-home-cta-hero__header-animate-item.slide-out{display:inline-block;transform:translateX(-100%);opacity:0;animation:slideOut .5s}
