.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-cta-strap .section .container{display:flex;justify-content:space-between;align-items:center}@media screen and (max-width: 767px){.purdue-home-cta-strap .section .container{flex-direction:column;align-items:flex-start}}.purdue-home-cta-strap .section .container.has-none-background{color:#000 !important;background:#fff}.purdue-home-cta-strap .section .container.has-none-background .purdue-home-cta-strap__content{color:#000 !important}.purdue-home-cta-strap .section .container.has-black-background{color:#fff !important}.purdue-home-cta-strap .section .container.has-black-background .purdue-home-cta-strap__content,.purdue-home-cta-strap .section .container.has-black-background .purdue-home-cta-strap__subTitle{color:#fff !important}.purdue-home-cta-strap--wrap{display:flex;flex:none}@media screen and (max-width: 1023px){.purdue-home-cta-strap--wrap{flex-direction:column;margin-top:1.5rem}}.purdue-home-cta-strap--wrap a:not(:last-child){margin-right:15px}@media screen and (max-width: 1023px){.purdue-home-cta-strap--wrap a:not(:last-child){margin-right:0;margin-bottom:15px}}.purdue-home-cta-strap__container{padding:2rem 4rem}@media screen and (max-width: 767px){.purdue-home-cta-strap__container{padding:2rem 1.25rem}}.purdue-home-cta-strap__container--right{display:flex;flex:none}@media screen and (max-width: 1023px){.purdue-home-cta-strap__container--right{flex-direction:column;margin-top:1.5rem}}.purdue-home-cta-strap__container--right a:not(:last-child){margin-right:15px}@media screen and (max-width: 1023px){.purdue-home-cta-strap__container--right a:not(:last-child){margin-right:0;margin-bottom:15px}}.purdue-home-cta-strap__container--right-wrap{display:flex;flex-direction:column;flex:none}.purdue-home-cta-strap__container--right-wrap a{display:flex;flex:0 0 100%}.purdue-home-cta-strap__container--right-wrap a:not(:last-child){margin-bottom:15px;margin-right:0}.purdue-home-cta-strap__subTitle{font-size:18px;font-weight:700;line-height:24px;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";letter-spacing:2.5px;text-transform:uppercase;margin-bottom:1rem !important;display:block}.purdue-home-cta-strap__content{font-size:2rem;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-weight:700;letter-spacing:0;line-height:1.2;margin-right:3rem;margin-bottom:0 !important;max-width:1050px}@media screen and (max-width: 767px){.purdue-home-cta-strap__content{margin-right:0;margin-bottom:2rem;max-width:100%}}.post-content .purdue-home-cta-strap--image .purdue-home-cta-strap__container,.wp-block-columns .purdue-home-cta-strap--image .purdue-home-cta-strap__container{padding:2rem}.purdue-home-cta-strap--image{margin-bottom:2rem}.purdue-home-cta-strap--image .image{position:relative;width:60px;height:60px;margin-right:20px}.purdue-home-cta-strap--image .purdue-home-cta-strap__container{display:flex;justify-content:space-between;flex-wrap:wrap}@media screen and (max-width: 767px){.purdue-home-cta-strap--image .purdue-home-cta-strap__container{padding:2rem 1.25rem}}.purdue-home-cta-strap--image .purdue-home-cta-strap__container .purdue-home-cta-strap__subTitle{font-weight:900;font-family:acumin-pro,"Franklin Gothic",sans-serif;color:#8e6f3e;line-height:1;font-size:1rem;margin-bottom:.5rem !important;letter-spacing:0}.purdue-home-cta-strap--image .purdue-home-cta-strap__container .purdue-home-cta-strap__container--left{display:flex}.purdue-home-cta-strap--image .purdue-home-cta-strap__container .purdue-home-cta-strap__container--right{align-content:end;flex-direction:row;flex-wrap:wrap}
