!function(){const e=document.querySelectorAll(".flipping-card");e.length>0&&e.forEach(e=>{e.querySelectorAll(".flipping-icon").forEach(i=>{i.addEventListener("click",()=>{e.classList.toggle("flipped");let i=!1;e.classList.contains("flipped")&&(i=!0);const t=i?".flipping-icon.back":".flipping-icon.front";e.querySelector(".flipping-icon.front").setAttribute("tabindex",i?-1:0),e.querySelector(".flipping-card-front").setAttribute("aria-hidden",!!i),e.querySelector(".flipping-icon.back").setAttribute("tabindex",i?0:-1),e.querySelector(".flipping-card-back").setAttribute("aria-hidden",!i),e.querySelector(".flipping-card-front").inert=!!i,e.querySelector(".flipping-card-back").inert=!i,e.querySelector(t).focus()})})})}();