<?php return array('dependencies' => array('react', 'wp-block-editor', 'wp-blocks', 'wp-components', 'wp-components/build-types/context', 'wp-i18n', 'wp-primitives', 'wp-server-side-render'), 'version' => '2bc5e3d6812adf29915a');
