.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-link-hero .section.has-padding-exlarge{padding-top:8rem;padding-bottom:3rem;height:100%}@media screen and (max-width: 767px){.purdue-home-link-hero .section.has-padding-exlarge{padding-top:4rem;padding-bottom:1.875rem}}.purdue-home-link-hero .container{display:flex;align-items:center;flex-direction:column;height:100%}.purdue-home-link-hero__subheader{margin-bottom:3.375rem !important}@media screen and (max-width: 767px){.purdue-home-link-hero__subheader{margin-bottom:2.5rem !important}}.purdue-home-link-hero__header{color:#fff;margin-bottom:1.25rem !important}.purdue-home-link-hero__subtext{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:1.25rem;letter-spacing:0;line-height:1.4;text-align:center;margin-bottom:4rem !important;max-width:840px}@media screen and (max-width: 767px){.purdue-home-link-hero__subtext{font-size:1rem}}.purdue-home-link-hero__arrow{margin-top:auto}.purdue-home-link-hero__arrow>*{color:#cfb991}.purdue-home-link-hero__list-container{display:flex;flex-direction:row;align-items:center;width:100%;max-width:1200px}@media screen and (max-width: 767px){.purdue-home-link-hero__list-container{flex-direction:column;align-items:flex-start}}.purdue-home-link-hero__list--desktop{display:flex;flex-wrap:wrap;width:100%;justify-content:space-between;list-style-type:none !important;z-index:1;position:relative;padding-left:0 !important;padding-bottom:0 !important}.purdue-home-link-hero__list--desktop:after{content:"";position:absolute;height:100%;width:100%;top:50%;transform:translateY(-50%);background-position:center;background-size:10px 2px;background-repeat:repeat-x;background-image:linear-gradient(to right, #fff 20%, rgba(255, 255, 255, 0) 0%)}@media screen and (max-width: 1023px){.purdue-home-link-hero__list--desktop{display:none}}.purdue-home-link-hero__list--desktop li,.purdue-home-link-hero__list--desktop div{z-index:2;padding-bottom:0 !important}.purdue-home-link-hero__list--desktop .purdue-home-button.purdue-home-button--white{font-size:1rem}.purdue-home-link-hero__list--desktop .purdue-home-button.purdue-home-button--white:after{content:none}.purdue-home-link-hero__list--mobile.purdue-home-select{display:none}.purdue-home-link-hero__list--mobile.purdue-home-select select{width:100%}@media screen and (max-width: 1023px){.purdue-home-link-hero__list--mobile.purdue-home-select{display:flex;width:100%;max-width:800px;margin:0 auto}}.purdue-home-link-hero__list-desc{font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-size:1.125rem;font-weight:900;letter-spacing:2.25px;line-height:1.1;color:#cfb991;text-transform:uppercase;margin-right:1.5rem;flex-shrink:0}@media screen and (max-width: 767px){.purdue-home-link-hero__list-desc{margin-right:0;margin-bottom:.7rem}}.purdue-home-link-hero .purdue-home-link-hero__subtext+ul.purdue-home-button-list{margin-top:-1.5rem}.purdue-home-link-hero ul.purdue-home-button-list{padding-left:0;margin-bottom:3rem}.hero-down-arrow{display:flex;justify-content:center}.hero-down-arrow>*{position:relative;color:#cfb991;margin-top:3rem;font-size:2rem;cursor:pointer;animation-name:bounce;animation-duration:2s;animation-iteration-count:2;animation-fill-mode:forwards}.hero-down-arrow>*:hover,.hero-down-arrow>*:focus{opacity:.9}@media(max-width: 1199px){.hero-down-arrow>*{width:35px}}@media(max-width: 767px){.hero-down-arrow>*{margin-top:1.75rem}}@media(prefers-reduced-motion: reduce){.hero-down-arrow>*{animation-play-state:paused !important}}@media screen and (min-width: 1216px){.has-global-header .purdue-home-link-hero{height:auto}}@keyframes bounce{0%,20%,50%,80%,100%{transform:translateY(0)}40%{transform:translateY(-15px)}60%{transform:translateY(-5px)}}
