.cta-link {
  font-family: $united-sans-condensed;
  font-weight: 900;
  letter-spacing: 2px;
  font-size: 1.125rem;
  line-height: 1.2;
  text-transform: uppercase;
  position: relative;
  text-align: center;
  padding-bottom: 0.1rem;
  cursor: pointer;
  &:after {
    content: "";
    width: 100%;
    border: 1px solid $boiler-gold;
    background: $boiler-gold;
    bottom: 0;
    left: 0;
    position: absolute;
    visibility: hidden;
    transform: scaleX(0);
    transition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
  }
  &:hover {
    &:after {
      visibility: visible;
      transform: scaleX(1);
    }
  }
}
a {
  color: $aged-gold;
  text-decoration: underline;
  font-weight: 600;
  &:hover {
    text-decoration: none;
  }
}
