.slider-controls {
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 2;
  position: relative;
  &.hidden {
    display: none;
  }
  &--dark {
    .glide__bullet {
      background-color: #000;
      border: 2px solid #fff;
      opacity: 1;
     
      &--active {
        background: #fff;
        opacity: 1;
        &:hover {
          background: #fff;
          opacity: 1;
        }
      }
      &:hover {
        opacity: 0.7;
      }
    }
    .glide__arrow {
      &.arrow--left {
        margin-right: 1rem;
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23ffffff' d='M9.4 233.4c-12.5 12.5-12.5 32.8 0 45.3l160 160c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L109.2 288 416 288c17.7 0 32-14.3 32-32s-14.3-32-32-32l-306.7 0L214.6 118.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0l-160 160z'/%3E%3C/svg%3E");
      }
      &.arrow--right {
        margin-left: 1rem;
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23ffffff' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
      }
    }
  }
}
.glide__bullets {
  display: flex;
  justify-content: center;
  align-items: center;
}
.glide__bullet {
  width: 0.75rem;
  height: 0.75rem;
  border: 2px solid $black;
  border-radius: 50%;
  margin: 0.5rem 1rem;
  display: inline-block;
  padding: 0;
  opacity: 1;
  background-color: transparent;
  cursor: pointer;
   &::before{
          content: "";
            padding: .25rem .75rem;
            position: relative;
            left: -9px;
            top: -6px;
      }
  &--active {
    background: $black;
    opacity: 1;
    &:hover {
      background: $black;
      opacity: 1;
    }
  }
  &:hover {
    opacity: 1;
  }
}
.glide__arrow {
  position: relative;
  overflow: hidden;
  text-indent: -9999px;
  background-repeat: no-repeat;
  background-position: 50%;
  border: none;
  box-shadow: none;
  transform: none;
  width: 20px;
  background-color: transparent;
  opacity: 0.75;
  &:hover {
    filter: invert(0);
    opacity: 1;
    cursor: pointer;
  }
  &.arrow--left {
    margin-right: 1rem;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath d='M9.4 233.4c-12.5 12.5-12.5 32.8 0 45.3l160 160c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L109.2 288 416 288c17.7 0 32-14.3 32-32s-14.3-32-32-32l-306.7 0L214.6 118.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0l-160 160z'/%3E%3C/svg%3E");
  }
  &.arrow--right {
    margin-left: 1rem;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
  }
}