.purdue-accordion {
  &.accordion--campus {
    background: none;
    margin-bottom: 0;
    .accordion__heading {
      color: $white;
      background: none;
      border: none;
      text-transform: uppercase;
      font-size: 1rem;
      padding: 0 2rem 0 0;
      position: relative;
      cursor: pointer;
      @include mobile {
        font-size: 0.875rem;
        padding: 0 2rem 0 0;
      }
      &:before {
        content: "";
        height: 3px;
        position: absolute;
        display: block;
        visibility: visible;
        background: #cfb991;
        -webkit-transform: scaleX(1);
        transform: scaleX(1);
        transition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
        bottom: -3px;
        left: 0;
        width: calc(100% - 30px);
      }
      &:after {
        content: "";
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' height='1em' viewBox='0 0 512 512'%3E%3C!--! Font Awesome Free 6.4.2 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23cfb991' d='M233.4 406.6c12.5 12.5 32.8 12.5 45.3 0l192-192c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L256 338.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l192 192z'/%3E%3C/svg%3E");
        right: 0;
        top: 5px;
        width: 16px;
        height: 16px;
        background-repeat: no-repeat;
        background-size: cover;
        color: $boiler-gold;
        position: absolute;
        transition: all 0.3s;
      }
      &.is-open {
        &:after {
          transform: rotate(-180deg);
        }
      }
    }
    .accordion__content {
      background-color: #fff;
      border-bottom-left-radius: 6px;
      border-bottom-right-radius: 6px;
      border-top: 2px solid #ededed;
      box-shadow: 0 8px 8px rgba(0, 0, 0, 0.1);
      display: none;
      font-size: 0.875rem;
      left: 0;
      position: absolute;
      top: 100%;
      z-index: 20;
      padding: 0.5rem 0;
      &.show {
        display: block;
      }
      li {
        a {
          color: #000;
          font-weight: 600;
          padding: 0.5rem 0.75rem;
          text-decoration: underline;
          &:hover {
            text-decoration: none;
          }
        }
      }
    }
  }
}
@keyframes fadeIn {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
