.purdue-home-select,
.year-month-filter {
  display: flex;
  align-items: center;
  justify-content: center;
  @include mobile {
    flex-direction: column;
  }
  select {
    height: auto;
    font-size: 1.25rem;
    line-height: 1.5;
    font-family: $acumin-pro;
    font-weight: 600;
    letter-spacing: 0;
    margin-right: 1.25rem;
    width: 660px;
    max-width: 100%;
    padding: 0.875rem 4rem 0.875rem 2rem;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    border: 0.5px solid $steam-gray;
    border-radius: 4px;
    background-color: $white;
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 512 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%238e6f3e' d='M233.4 406.6c12.5 12.5 32.8 12.5 45.3 0l192-192c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L256 338.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l192 192z'/%3E%3C/svg%3E");
    background-position:
      right 1rem top 50%,
      0 0;
    background-size:
      1.8rem auto,
      100%;
    background-repeat: no-repeat;
    box-shadow: $box-shadow;
    color: $black;
    &::-ms-expand {
      display: none;
    }
    @include mobile {
      font-size: 1.125rem;
      line-height: 1.5;
      height: auto;
      padding: 0.875rem 2rem 0.875rem 1rem;
      background-position:
        right 0.5rem top 50%,
        0 0;
      background-size:
        1.3rem auto,
        100%;
      margin: 0 0 1rem 0;
    }
    &.has-select-expand {
      overflow-y: visible;
      background-position:
        right 1rem top 15px,
        0 0;
    }
  }
  .purdue-home-button {
    flex-shrink: 0;
  }
}
