.purdue-home-intro-text-editor{
   .tagged-header-container .tagged-header{
      margin:0;
   }
   .purdue-home-intro-text__header{
      margin-top:0;
      margin-bottom: 0;
      line-height: 1;
   }
 }
