!function(){"use strict";var e=window.wp.blocks,t=window.wp.blockEditor,a=window.wp.components;const r=[["core/paragraph",{placeholder:"Add tab content"}]];var l=JSON.parse('{"UU":"purdue/tab-block"}');function n(){return n=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var r in a)({}).hasOwnProperty.call(a,r)&&(e[r]=a[r])}return e},n.apply(null,arguments)}var o=[{attributes:{aria:{type:"string",default:""},editorSelected:{type:"boolean",default:!1},selected:{type:"boolean",default:!1},anchorId:{type:"string"}},supports:{className:!1},save:e=>{const{attributes:a}=e,r=t.useBlockProps.save({className:"purdue-home-tabs__panel"+(a.editorSelected?" active":""),id:`panel-${a.aria}`,"aria-labelledby":`header-${a.aria}`,role:"tabpanel",...a.anchorId&&{"data-name":a.anchorId}});return React.createElement("div",r,React.createElement(t.InnerBlocks.Content,null))}},{attributes:{aria:{type:"string",default:""},editorSelected:{type:"boolean",default:!1},selected:{type:"boolean",default:!1},anchorId:{type:"string"}},supports:{className:!1},save:e=>React.createElement("div",{className:"purdue-home-tabs__panel"+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},React.createElement(t.InnerBlocks.Content,null))},{attributes:{aria:{type:"string",default:""},editorSelected:{type:"boolean",default:!1},selected:{type:"boolean",default:!1},anchorId:{type:"string"}},supports:{className:!1},save:e=>React.createElement("div",n({className:"purdue-home-tabs__panel"+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},e.attributes.anchorId?{"data-name":e.attributes.anchorId}:{}),React.createElement(t.InnerBlocks.Content,null))}];(0,e.registerBlockType)(l.UU,{save:e=>{const{attributes:a}=e,r=t.useBlockProps.save({className:"purdue-home-tabs__panel"+(a.editorSelected?" active":""),id:`panel-${a.aria}`,"aria-labelledby":`header-${a.aria}`,role:"tabpanel",tabindex:0,...a.anchorId&&{"data-name":a.anchorId}});return React.createElement("div",r,React.createElement(t.InnerBlocks.Content,null))},edit:e=>{const l=(0,t.useBlockProps)(),n=e.attributes.anchorId;return[React.createElement(t.InspectorControls,{key:"1"},React.createElement(a.PanelBody,null,React.createElement(a.PanelRow,null,React.createElement(a.TextControl,{label:"HTML Anchor",help:"Enter a word without spaces to make a unique web address just for this block, called an “anchor.” It must be unique from any other anchors on the page. Then, you’ll be able to link directly to this section of your page.",value:n||"",onChange:t=>e.setAttributes({anchorId:t})})))),React.createElement("div",l,React.createElement("div",{className:"purdue-home-tabs__panel "+(e.attributes.editorSelected?" active":""),role:"tabpanel"},React.createElement(t.InnerBlocks,{template:r,templateLock:!1,templateInsertUpdatesSelection:!1})))]},deprecated:o})}();