//import 'core-js/stable'
import "./accordion.js";
import "./accessibility";
import "./hideAjaxLoadMoreButton";
import "./to-top.js";
import "./currentPage";
import "./table";
import "./navigation.js";
import "./search.js";
import "./video.js";
import "./modal.js";
import "./select.js";
import "./slider.js";
//blocks

