@import "../../../node_modules/bulma/bulma.sass";
@import "../front-end/overides/variables";
@import "../front-end/overides/colors";
@import "../../style/front-end/components/background.scss";
@import "../../style/front-end/components/section.scss";
@import "../../style/front-end/components/search-box.scss";
@import "../../style/front-end/components/button.scss";
@import "../../style/front-end/components/headings.scss";
@import "../../style/front-end/components/post.scss";
@import "../../style/front-end/overides/list.scss";
@import "../../style/front-end/components/slider.scss";
@import "../../style/front-end/components/cta-card.scss";
@import "../../style/front-end/components/cta-banner.scss";
@import "../../style/front-end/components/home-select.scss";
@import "../../style/front-end/components/link.scss";
@import "../../style/front-end/components/navigation.scss";
@import "../../style/front-end/components/figure.scss";
@import "../../style/front-end/components/callout.scss";
@import "../../style/front-end/components/paragraphInitial.scss";
@import "../../style/front-end/components/misc.scss";

@import "./headings.scss";

input[name="search_engine_code"] {
  display: none;
}

.search_engine_code {
  display: none;
}

.dashicons-plus {
  padding-top: 0.3rem;
}

.dashicons-no {
  padding-top: 0.25rem;
}

.admin-footer-section {
  border-top: solid;
  padding-top: 1rem;
}

.wp-block {
  max-width: 1080px;
}

.block-editor-block-list__layout
  .block-editor-block-list__block.is-selected
  > .block-editor-block-list__block-edit {
  &:before {
    border-color: #00c4a7 !important;
  }

  &:after {
    border-color: #00c4a7 !important;
  }
}

.block-editor-block-list__layout
  .block-editor-block-list__block.has-child-selected
  > .block-editor-block-list__block-edit {
  &:before {
    border-color: #00c4a7 !important;
  }

  &:after {
    border-color: #00c4a7 !important;
  }
}

.content {
  figure {
    margin: 0 !important;
  }
}

.acf-input-wrap {
  .field-label {
    text-align: left !important;
  }
}

.tags {
  display: table !important;
}
.components-panel__row .components-base-control {
  width: 100%;
}

//This should be global to match others can make another class for different
.second-level-page-heading {
  text-align: left !important;
  max-width: 765px;
  margin-bottom: 1.25rem;
}
.editor-styles-wrapper p {
  line-height: 1.3 !important;
}
.purdue-home-cta-card .cta-icon {
  font-size: 2.5rem;
}
.purdue-initial-words-wrap {
  margin-bottom: 1.875rem;
  max-width: 1080px;
  margin-left: auto;
  margin-right: auto;
  .purdue-initial-words {
    margin-bottom: 0;
    margin-right: 0.5rem;
    font-family: $united-sans;
    font-size: 1.125rem;
    font-style: normal;
    font-weight: 700;
    line-height: 1.56;
  }
  .purdue-initial-words + p {
    display: inline;
  }
}
html :where(.wp-block)[data-align="left"] > figure {
  width: 100%;
}
html.wp-toolbar {
  height: auto;
  min-height: 100vh;
  body {
    min-height: 100vh;
  }
}
.theme-browser .theme .theme-name {
  height: auto;
}
.edit-post-visual-editor ol li {
  ol:not([type]) {
    list-style-type: lower-alpha !important;
    li {
      ol:not([type]) {
        list-style-type: lower-roman !important;
      }
    }
  }
}
.edit-post-visual-editor {
  ul,
  ol {
    font-size: 1rem;
    padding-left: 2.5rem;
    padding-bottom: 1.25rem;
    li {
      padding-bottom: 1rem;
    }
    @media (max-width: 767px) {
      padding-left: 1.5rem;
    }
    ul,
    ol {
      padding-top: 1rem;
      padding-bottom: 0;
      li:last-child {
        padding-bottom: 0.5rem;
      }
    }
  }
  ul.block-editor-block-list__block {
    list-style-type: square;
    ul {
      list-style-type: disc;
    }
  }
}
h1.wp-block-post-title {
  margin-bottom: 2rem;
}
