.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-media-grid .columns{flex-direction:row-reverse}.purdue-home-media-grid .columns .column{display:flex;flex-direction:column;gap:10px;justify-content:space-between}.purdue-home-media-grid .columns .column.is-three-fifths .image:nth-child(2){order:2}.purdue-home-media-grid .columns .column.is-three-fifths{width:62%}@media screen and (max-width: 1215px){.purdue-home-media-grid .columns .column.is-three-fifths{width:60%}}@media screen and (max-width: 767px){.purdue-home-media-grid .columns .column.is-three-fifths{width:100%}}.purdue-home-media-grid .columns .column.is-two-fifths{width:38%}@media screen and (max-width: 1215px){.purdue-home-media-grid .columns .column.is-two-fifths{width:40%}}@media screen and (max-width: 767px){.purdue-home-media-grid .columns .column.is-two-fifths{display:none}}.purdue-home-media-grid__content-wrap{width:100%;display:flex;justify-content:flex-end;align-items:center;z-index:2}@media screen and (max-width: 767px){.purdue-home-media-grid__content-wrap{position:relative}}.purdue-home-media-grid__content{padding-left:3rem;padding-right:3rem;background:hsla(0,0%,100%,.65);padding-top:1rem;padding-bottom:1rem}@media screen and (max-width: 1215px){.purdue-home-media-grid__content{padding-left:1.5rem;padding-right:1.5rem}}@media screen and (max-width: 767px){.purdue-home-media-grid__content{width:100%;padding-left:0;padding-right:0}}.purdue-home-media-grid__content p{font-size:1.125rem}@media screen and (max-width: 767px){.purdue-home-media-grid__content ul.purdue-home-button-list{justify-content:center}}@media screen and (max-width: 767px){.purdue-home-media-grid__content ul.purdue-home-button-list li{width:auto}}.purdue-home-media-grid__header{color:#000;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:3rem;font-weight:700;letter-spacing:0;line-height:1.05;margin-bottom:2rem !important}@media screen and (max-width: 1215px){.purdue-home-media-grid__header{font-size:2rem;margin-bottom:1rem !important}}@media screen and (max-width: 767px){.purdue-home-media-grid__header{text-align:center}}.purdue-home-media-grid__subtext{color:#000}@media screen and (max-width: 1215px){.purdue-home-media-grid__subtext{font-size:1rem;margin-bottom:1rem !important}}@media screen and (max-width: 767px){.purdue-home-media-grid__subtext{text-align:center;font-size:1.125rem}}.purdue-home-media-grid .image img,.purdue-home-media-grid .image video{object-fit:cover;position:absolute;width:100%;height:100%;top:0;left:0;border-radius:4px}.purdue-home-media-grid.has-black-background .purdue-home-media-grid__content{background:rgba(0,0,0,.65)}.purdue-home-media-grid.has-black-background .purdue-home-media-grid__header{color:#cfb991}.purdue-home-media-grid.has-black-background .purdue-home-media-grid__subtext{color:#fff}.purdue-home-media-grid .purdue-home-button-list{justify-content:flex-start;padding-left:0}.purdue-home-media-grid .purdue-home-button-list li:first-child{padding-left:0}
