@import "./overides/all";
// @import "../../../node_modules/bulma/bulma.sass";
@import '../../../node_modules/bulma/sass/utilities/all.sass';
@import '../../../node_modules/bulma/sass/helpers/all.sass';
@import '../../../node_modules/bulma/sass/base/all.sass';
@import '../../../node_modules/bulma/sass/grid/columns.sass';
@import '../../../node_modules/bulma/sass/layout/section.sass';
@import '../../../node_modules/bulma/sass/elements/box.sass';
@import '../../../node_modules/bulma/sass/elements/container.sass';
@import '../../../node_modules/bulma/sass/elements/image.sass';
@import '../../../node_modules/bulma/sass/elements/icon.sass';
@import '../../../node_modules/bulma/sass/components/card.sass';
@import '../../../node_modules/bulma/sass/components/media.sass';
@import '../../../node_modules/bulma/sass/components/level.sass';
@import '../../../node_modules/bulma/sass/components/modal.sass';
@import '../../../node_modules/bulma/sass/components/navbar.sass';
@import "./components/all";
@import "node_modules/@glidejs/glide/src/assets/sass/glide.core";