window.addEventListener("load",()=>{const e=[...document.querySelectorAll(".purdue-home-path-way.purdue-home-path-way--has-connector .purdue-home-path-way__connector")],t=window.innerHeight;e&&e.length>0&&window.addEventListener("scroll",()=>{e.forEach(e=>{const n=e.getBoundingClientRect().top,o=e.getBoundingClientRect().bottom;n<=.6*t&&e.classList.add("animate"),o<=.5*t&&e.classList.add("no-animate")})})});