.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-search-bar{overflow:hidden}.purdue-home-search-bar.has-black-background .purdue-home-search-bar__links{color:#c4bfc0}.purdue-home-search-bar.has-black-background .purdue-home-search-bar__links ul li a{color:#c4bfc0}.purdue-home-search-bar hr{background-color:#c4bfc0;height:1px;margin:0 auto;width:95%}@media screen and (max-width: 767px){.purdue-home-search-bar hr{width:100%}}.purdue-home-search-bar__header{font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-size:1.5rem;font-weight:900;letter-spacing:1.85px;line-height:1.5;text-align:center;margin-bottom:2rem}@media screen and (max-width: 767px){.purdue-home-search-bar__header{font-size:1.25rem;margin-bottom:1.5rem}}
