h1 {
  font-family: $acumin-pro;
  font-size: 3rem;
  font-style: normal;
  font-weight: 700;
  line-height: 1.167;
  color: $black;
  &:not(:first-child) {
    margin-top: 2.875rem;
  }
  &:not(:last-child) {
    margin-bottom: 3.5rem;
    @include mobile {
      margin-bottom: 2.5rem;
    }
  }
  @include touch {
    font-size: 2.875rem;
    line-height: 1.15;
  }
  @include mobile {
    font-size: 2.125rem;
  }
}
h2 {
  font-size: 2.25rem;
  font-weight: 700;
  font-family: $acumin-pro;
  color: $black;
  line-height: 1.167;
  &:not(:first-child) {
    margin-top: 2.75rem;
  }
  &:not(:last-child) {
    margin-bottom: 1.875rem;
  }
  @include mobile {
    font-weight: 700;
    font-size: 1.625rem;
    line-height: 1.25;
  }
}

h3 {
  font-size: 1.625rem;
  font-weight: 700;
  font-family: $acumin-pro;
  color: $black;
  line-height: 1.15;
  &:not(:first-child) {
    margin-top: 2.5rem;
  }
  &:not(:last-child) {
    margin-bottom: 1rem;
  }
  @include mobile {
    font-size: 1.375rem;
    line-height: 1.25;
  }
}

h4 {
  color: $black;
  font-weight: 500;
  font-size: 1.375rem;
  font-family: $acumin-pro;
  line-height: 1.27;
  &:not(:last-child) {
    margin-bottom: 1rem;
  }
  &:not(:first-child) {
    margin-top: 1.25rem;
  }
  @include mobile {
    font-size: 1.25rem;
    line-height: 1.3;
  }
}

h5 {
  font-weight: 700;
  font-size: 1.25rem;
  color: black;
  font-family: $united-sans-condensed;
  line-height: 1.3;
  letter-spacing: 0.1875rem;
  text-transform: uppercase;
  &:not(:last-child) {
    margin-bottom: 1rem;
  }
  &:not(:first-child) {
    margin-top: 1.25rem;
  }
  @include mobile {
    font-size: 1.125rem;
    line-height: 1.33;
  }
}

h6 {
  font-weight: 700;
  font-size: 1 rem;
  font-family: $united-sans;
  line-height: 1.125;
  text-transform: uppercase;
  color: black;
  &:not(:last-child) {
    margin-bottom: 1rem;
  }
  &:not(:first-child) {
    margin-top: 1.25rem;
  }
  @include mobile {
    font-size: 1rem;
    line-height: 1.375;
  }
}

p {
  font-size: 1rem;
  line-height: 1.75;
  &:not(:last-child) {
    margin-bottom: 1.875rem;
  }
}

.tagged-header {
  display: inline-block;
  padding: 0.675rem 1.5rem;
  background: $black;
  color: $white;
  font-family: $united-sans-condensed !important;
  font-size: 1.125rem !important;
  font-weight: 900;
  letter-spacing: 2.81px;
  line-height: 1 !important;
  border-radius: 4px;
  text-transform: uppercase;
  z-index: 1;
  position: relative;
  @include mobile {
    font-size: 1rem !important;
    padding: 0.5rem 1rem;
  }
  &--gold {
    background: $boiler-gold;
    color: $black !important;
  }
  &--white {
    background-color: $white;
    color: $black !important;
  }
  &:before {
    position: absolute;
    top: 0;
    left: -5px;
    height: 100%;
    content: "";
    background: inherit;
    z-index: -1;
    width: calc(100% + 10px);
    transform: skewX(-15deg);
  }
}
.tagged-header-container {
  border-top: 2px solid $black;
  margin-left: 10px;
  &.tagged-header-container-gold {
    border-top: 2px solid $boiler-gold;
  }
  .tagged-header {
    border-radius: 0 0 4px 4px;
    top: -2px;
  }
}
.purdue-home-subheader {
  font-family: $united-sans-condensed;
  font-size: 1.125rem;
  font-weight: 900;
  letter-spacing: 3.12px;
  line-height: 1;
  text-align: center;
  color: $black;
}
h1.second-level-page-heading {
  font-family: $united-sans-condensed;
  font-size: 6rem;
  font-weight: 700;
  letter-spacing: 0;
  line-height: 0.9;
  text-align: center;
  max-width: 1061px;
  margin-top: 0;
  text-transform: uppercase;
  @include touch {
    font-size: 5rem;
  }
  @include mobile {
    font-size: 3.375rem;
  }
}
.purdue-home-intro-text__header {
  margin-top: 0 !important;
  &.header-font-acumin {
    font-family: $acumin-pro;
    font-weight: 700;
  }
  &.header-font-united {
    font-family: $united-sans-condensed;
    font-weight: 700;
    font-size: 1.75rem;
  }
}
h2.purdue-home-intro-text__header.header-font-acumin {
  font-size: 3.125rem;
  @include mobile {
    font-size: 2.75rem;
  }
}

.has-layout-two-line{
  h2.purdue-home-intro-text__header.header-font-acumin {
  font-size: 2rem;
  @include mobile {
    font-size: 1.75rem;
  }
}
}
h3.purdue-home-intro-text__header.header-font-acumin,
h4.purdue-home-intro-text__header.header-font-acumin,
h5.purdue-home-intro-text__header.header-font-acumin,
h6.purdue-home-intro-text__header.header-font-acumin,
p.purdue-home-intro-text__header.header-font-acumin {
  font-size: 2rem;
  @include mobile {
    font-size: 1.75rem;
  }
}
strong {
  color: inherit;
}
