!function(){"use strict";var e=window.wp.blocks,a=window.wp.blockEditor,l=JSON.parse('{"UU":"purdue/custom-container"}'),t=(window.wp.i18n,window.wp.components);function n(){return n=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var l=arguments[a];for(var t in l)({}).hasOwnProperty.call(l,t)&&(e[t]=l[t])}return e},n.apply(null,arguments)}const o=[["core/paragraph",{placeholder:"Body content copy"}]];var r=window.wp.primitives;(0,e.registerBlockType)(l.UU,{icon:()=>React.createElement(r.SVG,{id:"Layer_1","data-name":"Layer 1",xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 100 87.5"},React.createElement("defs",null),React.createElement("g",{id:"Window-maximize",className:"cls-1"},React.createElement("g",{className:"cls-1"},React.createElement(r.Path,{className:"color-d9ab28",d:"M100,16.62V85.37a9.38,9.38,0,0,1-9.37,9.37H9.37A9.38,9.38,0,0,1,0,85.37V16.62A9.38,9.38,0,0,1,9.37,7.24H90.63A9.38,9.38,0,0,1,100,16.62ZM90.63,38.49H9.37v45.7a1.18,1.18,0,0,0,1.18,1.18h78.9a1.18,1.18,0,0,0,1.18-1.18Z",transform:"translate(0 -7.24)"})))),edit:e=>{const{className:l,setAttributes:r}=e,{id:c,background:d,paddingTop:s,paddingBottom:i,sidePadding:u}=e.attributes,m=(0,a.useBlockProps)();return[React.createElement(a.InspectorControls,{key:"1"},React.createElement(t.PanelBody,null,React.createElement(t.PanelRow,null,React.createElement(t.RadioControl,{label:"Choose the background.",selected:d,options:[{label:"Gold",value:"gold"},{label:"Black",value:"black"},{label:"Gray",value:"gray"},{label:"Gray Gradient",value:"gradient"}],onChange:e=>r({background:e})})),React.createElement(t.PanelRow,null,React.createElement(t.SelectControl,{label:"Padding at the top",value:s,options:[{value:"has-padding-top-none",label:"None"},{value:"has-padding-top-small",label:"Small"},{value:"",label:"Medium"},{value:"has-padding-top-large",label:"Large"}],onChange:e=>{r({paddingTop:e})}})),React.createElement(t.PanelRow,null,React.createElement(t.SelectControl,{label:"Padding at the bottom",value:i,options:[{value:"has-padding-bottom-none",label:"None"},{value:"has-padding-bottom-small",label:"Small"},{value:"",label:"Medium"},{value:"has-padding-bottom-large",label:"Large"}],onChange:e=>{r({paddingBottom:e})}})),React.createElement(t.PanelRow,null,React.createElement(t.SelectControl,{label:"Padding on the side",help:"Standard side padding is the padding used for the page container.",value:u,options:[{value:"standard",label:"Standard"},{value:"no",label:"None"},{value:"small",label:"Small"},{value:"medium",label:"Medium"},{value:"large",label:"Large"}],onChange:e=>{r({sidePadding:e})}})),React.createElement(t.PanelRow,null,React.createElement(t.TextControl,{label:"HTML Anchor",help:"Enter a word without spaces to make a unique web address just for this block, called an “anchor.” It must be unique from any other anchors on the page. Then, you’ll be able to link directly to this section of your page.",value:c,onChange:e=>r({id:e})})))),React.createElement("div",n({key:"2"},m),React.createElement("div",{className:`purdue-home-custom-container has-${d}-background`},React.createElement("div",{className:`section has-${d}-background ${s?` ${s}`:""}${i?` ${i}`:""} has-${u}-sidepadding`},React.createElement(a.InnerBlocks,{template:o,templateLock:!1}))))]},save:()=>React.createElement(a.InnerBlocks.Content,null)})}();