import { SVG, Path } from '@wordpress/primitives';

const icon = () => (
	<SVG xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100">
		<Path d="M8,8 H42 V42 H8 Z M58,8 H92 V42 H58 Z M8,58 H42 V92 H8 Z M58,58 H92 V92 H58 Z M14,22 H36 M14,30 H30 M64,22 H86 M64,30 H80 M14,72 H36 M14,80 H30 M64,72 H86 M64,80 H80" stroke="#cfb991" strokeWidth="4" fill="none" strokeLinecap="round" />
	</SVG>
);

export default icon;
