/*
This file is responsible only for providing theme information that are displayed
in `Apperance > Themes`. Do not write in here any CSS declarations.

Theme Name: Purdue New Theme
Theme URI: https://marcom.purdue.edu/our-brand/digital/
Description: WordPress theme based on Purdue University digital brand standards 
Version: 1.1.49
Author: Purdue Marketing and Communicatons
Author URI: https://marcom.purdue.edu
Text Domain: purdue
License: GPLv3 License
License URI: https://www.gnu.org/licenses/gpl-3.0.en.html
*/
