.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-featured-story{position:relative}.purdue-home-featured-story .tagged-header-container{margin-bottom:2.5rem;border-color:#cfb991}@media screen and (max-width: 767px){.purdue-home-featured-story .tagged-header-container{margin-bottom:1.5rem}}.purdue-home-featured-story .has-gold-background .tagged-header-container{border-color:#000}.purdue-home-featured-story__container{justify-content:space-between}.purdue-home-featured-story__container--reversed{flex-direction:row-reverse}@media screen and (max-width: 767px){.purdue-home-featured-story__container{flex-direction:column}}.purdue-home-featured-story__container--50 .purdue-home-featured-story__content-container.column{flex-basis:48%}@media screen and (max-width: 767px){.purdue-home-featured-story__container--50 .purdue-home-featured-story__content-container.column{width:100%;flex-basis:100%}}.purdue-home-featured-story__container--50 .purdue-home-featured-story__image-container.column{flex-basis:50%}@media screen and (max-width: 767px){.purdue-home-featured-story__container--50 .purdue-home-featured-story__image-container.column{width:100%;flex-basis:100%}}.purdue-home-featured-story__content-container.column{flex-basis:42%;font-size:1.125rem;display:flex;flex-direction:column;justify-content:center;flex-grow:0}@media screen and (max-width: 767px){.purdue-home-featured-story__content-container.column{width:100%;padding:1.25rem;font-size:1rem}}.purdue-home-featured-story__content-container.column p,.purdue-home-featured-story__content-container.column ul{font-size:inherit}.purdue-home-featured-story__content-container .purdue-home-button-list{justify-content:flex-start;flex-wrap:wrap;padding-left:0}.purdue-home-featured-story__content-container .purdue-home-button-list li:before{content:none}.purdue-home-featured-story__content-container .purdue-home-button-list li:first-child{padding-left:0}.purdue-home-featured-story__image-container.column{flex-basis:56%;position:relative;flex-grow:0}@media screen and (max-width: 767px){.purdue-home-featured-story__image-container.column{width:100%}}.purdue-home-featured-story__image-container.column .image img{border-radius:4px;object-fit:cover}.purdue-home-featured-story__image-container.column .purdue-home-cta-card .image{width:100%}.purdue-home-featured-story__image-container.column .purdue-home-cta-card .image img{object-fit:cover;height:100%}@media screen and (min-width: 1024px){.purdue-home-featured-story__image-container.column .purdue-home-cta-card .cta-link{font-size:2.25rem}}@media screen and (min-width: 1024px){.purdue-home-featured-story__image-container.column .purdue-home-cta-card .cta-icon.cta-icon--play{width:70px;height:70px}}.purdue-home-featured-story__header{color:inherit;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:2.5rem;font-weight:700;letter-spacing:0;line-height:1.1;margin-bottom:1.5rem !important}@media screen and (max-width: 767px){.purdue-home-featured-story__header{font-size:2rem;margin-bottom:1.2rem !important}}
