@import "./colors";
$black: #000;

$footer-background-color:$black;
$tablet: 768px;
$mobile-plus:414px;
$stickySideNav-desktop: 1322px;
$stickySideNav-tablet: 1066px;
$text: $black;

$content-heading-color: $black;

$side-padding-desktop:3.25rem;
$side-padding-tablet:1.5rem;
$side-padding-mobile:1.25rem;
$box-shadow: 0 2px 5px 0 rgba(0,0,0,0.15);
$box-shadow-hover: 0 14px 28px rgba(0,0,0,0.25), 0 10px 10px rgba(0,0,0,0.22);

$acumin-pro-condensed: acumin-pro-condensed,
"Franklin Gothic",
sans-serif;
$acumin-pro-semicondensed: acumin-pro-semi-condensed,
"Franklin Gothic",
sans-serif;
$acumin-pro: acumin-pro,
"Franklin Gothic",
sans-serif;
$united-sans: "United Sans",
Impact,
"Arial Black",
"sans serif";
$united-sans-condensed: "United Sans Condensed",
Impact,
"Arial Black",
"sans serif";
$united-sans-extended: "United Sans Extended",
Impact,
"Arial Black",
"sans serif";

$source-serif-pro: source-serif-pro,Georgia,serif;
$family-sans-serif: acumin-pro,
"Franklin Gothic",
sans-serif;

.main-content {
    display: block;
}

.home{
    .content{
        margin-bottom: 0 !important;
    }
}
.main-content>.content:not(:last-child){
    margin-bottom: 0 !important;
}
.content p{
    max-width:100%;
}

@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
	.columns.is-multiline{
		flex-wrap:none;
	}
	.column{
		flex-basis:auto;
	} 
}

.box{
    border-radius: 4px !important;
}

@media (prefers-reduced-motion: reduce) { 
  html { scroll-behavior: auto; }
}

@media (prefers-reduced-motion: no-preference) {
  html { scroll-behavior: smooth; }
}