.sortable-posts{width:100%}.sortable-posts .components-panel__body{background:#eee;margin-bottom:10px}.sortable-posts .buttons{display:flex}.components-panel__row{min-height:0 !important}.purdue-home-cta-card--vertical .image.has-no-shade:after{content:none}
