@import "../../../src/style/front-end/overides/colors";
@import "../../../src/style/front-end/overides/variables";
@import '../../../node_modules/bulma/sass/utilities/mixins.sass';

.purdue-home-50-50-animated-header-animate.pause * {
  animation-play-state: paused;
}

@keyframes slideIn {
  0% {
    transform: translateX(-100%);
    opacity: 0;
  }

  100% {
    transform: translateX(0);
    opacity: 1;
  }
}

@keyframes slideOut {
  0% {
    opacity: 1;
    transform: translateX(0);
  }

  100% {
    opacity: 0;
    transform: translateX(100%);
  }
}

.purdue-home-50-50-animated-header {
  .column {
    flex-direction: column;
    display: flex;
    justify-content: center;
  }

  .column:first-child {
    z-index: 20;
    background: #fff;
  }

  .column:last-child {
    align-items: center;
  }

  .controls {
    display: flex;
    width: 100%;
    justify-content: flex-end;
    align-content: flex-end;
    flex-grow: 1;
    flex-wrap: wrap;
  }

  .cta-btnctrl {
    color: $aged-gold;
    font-size: 2rem;
    z-index: 2;
    background: none;
    border: none;
    cursor: pointer;
    padding: 0;
    line-height: 1;
  }

  h2.second-level-page-heading {
    font-family: $united-sans-condensed;
    font-size: 4.75rem;
    font-weight: 700;
    letter-spacing: 0;
    line-height: 0.9;
    text-align: center;
    max-width: 1061px;
    margin-top: 0;
    margin-bottom: 0;
    text-transform: uppercase;

    @include touch {
      font-size: 3.375rem;
      margin-bottom: 1.875rem;
    }

    @include mobile {
      font-size: 3.375rem;
    }
  }

  .purdue-home-cta-hero__header-static {
    position: relative;
    z-index: 1;
    background: $white;
    display: block;
    width: 100%;
  }

  .purdue-home-cta-hero__header-animate {
    display: block;
  }

  .purdue-home-cta-hero__header-animate-item {
    opacity: 0;
    position: relative;
    z-index: 0;
    transform: translateX(-100%);

    &.slide-in {
      display: inline-block;
      transform: translateY(0);
      opacity: 1;
      animation: slideIn 2s;
    }

    &.slide-out {
      display: inline-block;
      transform: translateX(-100%);
      opacity: 0;
      animation: slideOut 0.5s;
    }
  }

}