
.purdue-home--cta-card-block__content-container{
    width: 50%;
    padding: 4rem 3.5rem;
    font-size: 1.125rem;
 }
 .image-slider-editor{
    .buttons-container{
        padding-bottom:2rem;
    }
 }