.purdue-home-cta-card {
  text-decoration: none;
  position: relative;
  z-index: 1;
  box-shadow: $box-shadow;
  border-radius: 4px;
  overflow: hidden;
  display: block;
  &.purdue-home-cta-card--story {
    height: 100%;
    background: $white;
    display: flex;
    flex-direction: column;
    .image {
      overflow: hidden;
      &:after {
        background: none;
      }
      img {
        box-shadow: none;
        border-radius: 0;
        transition: all 0.3s;
      }
    }
    &.purdue-home-cta-card--news--plain {
      .image img {
        border-radius: 4px;
      }
    }
    .flex-container--align-center {
      padding: 1.25rem;
      height: 100%;
      position: relative;
      display: flex;
      flex-direction: column;
      justify-content: flex-start;
      align-items: flex-start;
      top: 0;
      .purdue-home-cta-grid__card-title {
        color: $black;
        font-family: $acumin-pro;
        font-size: 1.5rem;
        font-weight: 700;
        line-height: 1.25;
        margin-bottom: 0.75rem !important;
      }
      .purdue-home-cta-grid__card-subtitle {
        margin-bottom: 1.25rem !important;
        color: $cool-gray;
        font-family: $united-sans-condensed;
        font-size: 0.875rem;
        font-style: normal;
        font-weight: 800;
        line-height: 1.7;
        letter-spacing: 2px;
        text-transform: uppercase;
        display: flex;
        align-items: center;
        flex-wrap: wrap;
        span {
          padding-right: 0.25rem;
          &:not(:first-child) {
            padding-left: 0.5rem;
          }
          &.purdue-posttype-tag {
            display: flex;
            align-items: center;
            padding-right: 0.5rem;
            &:before {
              background-repeat: no-repeat;
              display: inline-block;
              margin-right: 0.5rem;
            }
          }
        }
      }
      .purdue-home-cta-grid__card-subtext {
        margin-bottom: 1.25rem;
        color: $black;
        font-family: $acumin-pro;
        font-size: 1rem;
        font-style: normal;
        font-weight: 400;
        line-height: 1.7;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        display: -webkit-box;
        overflow: hidden;
        text-overflow: ellipsis;
      }
      .purdue-home-button {
        border: 1px solid $boiler-gold !important;
        margin-top: auto;
      }
      &.has-black-background {
        .purdue-home-cta-grid__card-title,
        .purdue-home-cta-grid__card-subtitle,
        .purdue-home-cta-grid__card-subtext {
          color: $white;
        }
      }
      &.has-no-excerpt {
        .purdue-home-cta-grid__card-title {
          margin-bottom: 1.5rem !important;
        }
      }
    }
  }

  &.purdue-home-cta-card--faculty {
    height: 100%;
    background: $black;
    &:after {
      content: "";
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23ffffff' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
      height: 32px;
      width: 28px;
      background-repeat: no-repeat;
      background-size: cover;
      right: 1rem;
      font-size: 2rem;
      position: absolute;
      bottom: 1rem;
      transition: all 0.3s ease;
    }
    .image {
      overflow: hidden;
      &:after {
        background: linear-gradient(180deg, rgba(0, 0, 0, 0) 80%, #000000 100%);
      }
      img {
        box-shadow: none;
        border-radius: 0;
        transition: all 0.3s;
      }
    }
    .flex-container.flex-container--align-bottom {
      padding: 1.5rem 3.5rem 1.5rem 1.5rem;
      position: relative;
      z-index: 2;
      height: auto;
      display: flex;
      flex-direction: column;
      color: $white;
      &:not(:first-child) {
        margin-top: -4rem;
      }
      .purdue-home-cta-grid__card-title {
        color: $white;
        font-family: $acumin-pro-semicondensed;
        font-size: 1.5rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1.3;
        text-transform: capitalize;
        margin-bottom: 1rem !important;
      }
      .purdue-home-cta-grid__card-subtext,
      .purdue-home-cta-grid__card-subtext p {
        color: $boiler-gold;
        font-family: $acumin-pro;
        font-size: 1rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1.38;
        letter-spacing: 0.5px;
        -webkit-line-clamp: 2;
        -webkit-box-orient: vertical;
        display: -webkit-box;
        overflow: hidden;
        text-overflow: ellipsis;
        margin-bottom: 0;
        &:not(:last-child) {
          margin-bottom: 0.5rem;
        }
      }
      .purdue-home-cta-grid__tags {
        color: $boiler-gold;
        font-family: $acumin-pro;
        font-size: 1rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1.4;
      }
    }
  }

  &.purdue-home-cta-card--vertical {
    height: 100%;
    &:hover {
      .cta-link {
        text-decoration: underline;
      }
    }
    .image,
    .image img {
      height: 100%;
    }
    .flex-container--align-vertical-between {
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      z-index: 2;
      flex-direction: column;
      display: flex;
      justify-content: space-between;
      padding: 1rem;
    }
    .cta-link {
      text-align: left;
      font-family: $acumin-pro;
      font-size: 1.125rem;
      color: $white !important;
      letter-spacing: 0;
      font-weight: 600;
      line-height: 1.4;
      width: 80%;
      text-transform: none;
      text-decoration: none;
      cursor: pointer;
      margin-top: auto;
      &:after {
        content: none;
      }
      &:hover {
        text-decoration: underline;
      }
    }
  }
  &.purdue-home-cta-card--nolink {
    .image {
      &:after {
        content: none;
      }
    }
  }
  &__cta-text {
    font-family: $acumin-pro;
    font-size: 1rem;
    color: $boiler-gold;
    letter-spacing: 1px;
    text-transform: uppercase;
    font-weight: 800;
    position: relative;
    overflow: hidden;
    display: flex;
    justify-content: space-between;
    &:after {
      content: "";
      top: 50%;
      width: 100%;
      height: 2px;
      background: $boiler-gold;
      position: relative;
      margin-left: 1rem;
      flex: 1;
    }
  }
  .flex-container--align-center {
    position: absolute;
    top: 0.5rem;
    left: 0;
    width: 100%;
    height: 100%;
    z-index: 2;
    flex-direction: column;
    display: flex;
    align-items: center;
    justify-content: center;
    padding: 1rem;
  }
  .purdue-home-cta-card__link {
    color: $white;
  }
  .cta-icon {
    color: $boiler-gold;
    &.cta-icon--arrow {
      width: 72px;
      height: 72px;
    }
    &.cta-icon--play {
      width: 50px;
      height: 50px;
      margin-top: 0.5rem;
    }
  }
  .iframe-container {
    position: relative;
    padding-top: 56.25%;
    // display:none;
  }
  iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    object-fit: cover;
  }
  &:not(:last-child) {
    margin-bottom: 0.875rem;
  }
  .image {
    &:after {
      content: "";
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.55);
    }
    img {
      object-fit: cover;
    }
  }
  .modal-trigger {
    &:hover {
      .cta-link {
        &:after {
          visibility: visible;
          transform: scaleX(1);
        }
      }
    }
  }
  .flex-container--align-vertical-between {
    &:after {
      content: "";
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23cfb991' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
      height: 32px;
      width: 28px;
      background-repeat: no-repeat;
      background-size: cover;
      right: 0.5rem;
      font-size: 2.5rem;
      position: absolute;
      bottom: 0.5rem;
      transition: transform 0.3s ease;
    }
  }
  &.has-content-bottom {
    .image {
      img {
        transition: 0.3s ease;
      }

      &:after {
        background: linear-gradient(180deg, rgba(0, 0, 0, 0) 0%, #000000 100%);
      }
    }
  }
  .flex-container--align-bottom {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: flex-end;
    padding: 2.25rem 7rem 2.25rem 3.25rem;
    @include touch {
      padding: 1rem 5rem 1rem 1.5rem;
    }
  }
}
a.purdue-home-cta-card,
.purdue-home-cta-card.purdue-home-cta-card--video {
  cursor: pointer;
  &:hover {
    .cta-link {
      &:after {
        visibility: visible;
        transform: scaleX(1);
      }
    }
    .flex-container--align-vertical-between {
      &:after {
        transform: translateX(3px);
      }
    }
  }
}

a.purdue-home-cta-card.has-content-bottom {
  &:after {
    content: "";
    background-image: url("data:image/svg+xml,%3C%3Fxml version='1.0' encoding='UTF-8'%3F%3E%3Csvg width='104.253572px' height='104.253572px' viewBox='0 0 104.253572 104.253572' version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'%3E%3Ctitle%3Earrow_circle_icon%3C/title%3E%3Cg id='Desktop' stroke='none' stroke-width='1' fill='none' fill-rule='evenodd'%3E%3Cg id='arrow_circle_icon' transform='translate(52.1268, 52.1268) rotate(40) translate(-52.1268, -52.1268)translate(15.1268, 15.1268)' stroke='%23cfb991' stroke-width='4'%3E%3Cg id='Group-3' transform='translate(0, 0)'%3E%3Ccircle id='Oval-Copy' transform='translate(37, 37) rotate(135) translate(-37, -37)' cx='36.9999977' cy='36.9999977' r='25.1629493'%3E%3C/circle%3E%3Cg id='Arrow-Copy-3' transform='translate(27.7199, 21.7701)' stroke-linecap='round' stroke-linejoin='round'%3E%3Cline x1='9.52771771' y1='2.99227577' x2='9.56560625' y2='27.0777404' id='Path-6' transform='translate(9.5467, 15.035) rotate(50) translate(-9.5467, -15.035)'%3E%3C/line%3E%3Cpolyline id='Path-5' transform='translate(14.2315, 11.1834) rotate(50) translate(-14.2315, -11.1834)' points='4.73086087 17.2295253 14.1515077 5.10747085 23.7320575 17.2593992'%3E%3C/polyline%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
    height: 90px;
    width: 90px;
    background-repeat: no-repeat;
    background-size: cover;
    right: 0;
    position: absolute;
    bottom: 0;
    transition: transform 0.2s;
    @include mobile {
      height: 70px;
      width: 70px;
    }
  }

  &:hover {
    .image img {
      transform: scale(1.1);
    }
    &:after {
      transform: translateX(3px);
    }
  }
}
.purdue-home-cta-grid {
  &.has-black-background {
    .purdue-home-cta-grid__header,
    .purdue-home-cta-grid__card-title {
      color: $boiler-gold;
    }
    .purdue-home-cta-grid__content,
    .purdue-home-cta-grid__card-subtext,
    .purdue-home-cta-grid__card-subtitle {
      color: $white;
    }
  }
  &__intro {
    margin-bottom: 3rem;
    @include mobile {
      margin-bottom: 2rem;
    }
  }
  &__header.purdue-home-intro-text__header.header-font-united {
    text-align: center;
    margin-bottom: 0;
  }
  &__content {
    margin-top: 1rem;
    p {
      text-align: center;
    }
  }
  &__cards {
    width: 100%;
    .columns {
      justify-content: space-between;
    }
    .column {
      &.is-6-desktop {
        max-width: 511px;
        @include mobile {
          max-width: 100%;
        }
      }
      &.is-4-desktop {
        max-width: 440px;
        @include mobile {
          max-width: 100%;
        }
      }
    }
    .purdue-home-cta-card:not(
        .purdue-home-cta-card--story,
        .purdue-home-cta-card--faculty
      ) {
      .image {
        &:after {
          background: none;
        }
        img {
          width: 100%;
          height: 100%;
          box-shadow: $box-shadow;
          border-radius: 4px;
        }
      }
      .flex-container--align-center {
        position: relative;
        display: flex;
        flex-direction: column;
        justify-content: flex-start;
        align-items: flex-start;
        padding: 2rem 0;
        top: 0;
      }
    }
  }
  .purdue-home-cta-card.purdue-home-cta-card--stack {
    box-shadow: none;
    &.has-decoration-line {
      .purdue-home-cta-grid__card-title {
        justify-content: space-between;
        position: relative;
        width: 100%;
        align-items: center;
        display: flex;
        &:after {
          content: "";
          top: 50%;
          width: 100%;
          height: 2px;
          background: $steam-gray;
          position: relative;
          margin-left: 1rem;
          flex: 1;
        }
      }
    }
  }
  &__card-subtitle {
    font-family: $united-sans-condensed;
    font-size: 1.125rem;
    font-weight: 900;
    letter-spacing: 2.5px;
    line-height: 1.4;
    margin-bottom: 0.8rem !important;
  }
  &__card-title {
    color: $black;
    font-family: $acumin-pro;
    font-size: 2.5rem;
    font-weight: 700;
    letter-spacing: 0;
    line-height: 1.1;
    margin-bottom: 1.5rem !important;
    @include mobile {
      font-size: 2rem;
      margin-bottom: 1.2rem !important;
    }
  }
  &__card-subtext,
  &__card-subtext p {
    color: $black;
    font-family: $acumin-pro;
    font-size: 1rem;
    font-weight: 400;
    letter-spacing: 0;
    line-height: 1.5;
  }
  &__card-subtext {
    margin-bottom: 1.125rem;
  }
  .button-container {
    text-align: center;
  }
}
a.purdue-home-cta-card.purdue-home-cta-card--story {
  .flex-container--align-center.has-black-background {
    z-index: 0;
  }
  &:after {
    content: "";
    display: block;
    width: 100%;
    height: 4px;
    bottom: 0;
    position: absolute;
    transform: scaleX(0);
    transition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
    background: $railway-gray;
  }
  &:hover, &:focus {
    &:after {
      transform: scaleX(1);
    }
    button {
      background: $black;
      color: $white;
      &:after {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23cfb991' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
        transform: translateX(3px);
      }
    }
  }
}
a.purdue-home-cta-card.purdue-home-cta-card--faculty {
  &:before {
    content: "";
    display: block;
    width: 100%;
    height: 4px;
    bottom: 0;
    position: absolute;
    transform: scaleX(0);
    transition: all 0.25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
    background: $railway-gray;
  }
  &:hover {
    &:after {
      transform: translateX(3px);
    }
    &:before {
      content: "";
      transform: scaleX(1);
    }
  }
}
