//footer without sidenav style
body.custom-background {
  background-image: none !important;
}
.footer {
  padding: 6rem $side-padding-desktop 5rem;
  color: $white;
  background-position: center;
  background-size: cover;
  background-repeat: no-repeat;
  position: relative;
  &:after {
    content: "";
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: rgba(0, 0, 0, 0.88);
  }
  @include touch {
    padding: 6rem $side-padding-tablet 5rem;
  }
  @include mobile {
    padding: 3rem $side-padding-mobile 3rem;
  }
  h2 {
    color: $boiler-gold;
    font-family: $united-sans-condensed;
    font-size: 1rem;
    font-weight: 900;
    letter-spacing: 2px;
    line-height: 1.5;
    text-transform: uppercase;
  }
  p {
    color: $white;
  }
  a {
    color: $white;
    text-decoration: underline;
    &:hover {
      color: $white;
      text-decoration: none;
    }
  }
  a.purdue-home-button, a.wp-block-button__link.wp-element-button{  
    color: $black;
    text-decoration: none;
    &:hover {
      color: $white;
      text-decoration: none;
    }
    &.purdue-home-button--black{
      color: $white;
      &:hover{
        color: $black;
      }
    }
}
  .footer__global__resources {
    padding-bottom: 3rem;
    position: relative;
    z-index: 1;
  }
  .footer__links {
    margin-bottom: 1rem;
    display: flex;
    flex-direction: column;
    align-items: flex-start;
    @include touch {
      align-items: flex-start;
      margin-bottom: 0;
    }
    h2 {
      margin: 0 0 1.3rem 0;
      @include touch {
        width: 100%;
        margin: 0;
      }
      .accordion__heading--footer {
        width: 100%;
        padding: 0;
        margin: 0;
        border: 0;
        text-align: left;
        display: flex;
        flex-direction: row;
        justify-content: space-between;
        align-items: center;
        text-transform: uppercase;
        pointer-events: none;
        font-family: $united-sans-condensed;
        background: none;
        color: $boiler-gold;
        font-weight: 900;
        letter-spacing: 2px;
        line-height: 1.5;
        font-size: 1rem;
        .accordion__icon__plus {
          display: none;
          pointer-events: none;
          width: 24px;
          height: 24px;
          margin-left: 1rem;
          transition: all 0.3s ease;
        }
        &:focus {
          outline: none;
        }
        @include touch {
          pointer-events: all;
          padding: 1rem;
          &:hover {
            cursor: pointer;
          }
          .accordion__icon__plus {
            display: block;
            &.hide {
              transform: rotate(45deg);
            }
          }
        }
        @include mobile {
          padding: 0.75rem;
        }
      }
    }
    ul {
      font-family: $acumin-pro;
      @include touch {
        display: none;
        height: 0;
        transition: height 0.2s ease;
        overflow: hidden;
        width: 100%;
        padding: 0 1rem;
      }
      @include mobile {
        padding: 0 0.75rem;
      }
      &.show {
        display: block;
      }
      &.hide {
        display: none;
      }
      li {
        padding: 0.4rem 0;
        margin: 0;
        a {
          color: $white;
          font-size: 14px;
          text-decoration: none;
          font-weight: 400;
          &:hover {
            text-decoration: underline;
            color: $white;
          }
        }
        &:first-child {
          padding-top: 0;
        }
        &:last-child {
          padding-bottom: 0;
          @include touch {
            padding-bottom: 1rem;
          }
        }
      }
    }
  }
  .footer__signature {
    text-align: center;
    background-color: none;
    color: $white;
    font-size: 0.875rem;
    font-family: $source-serif-pro;
    position: relative;
    z-index: 1;
    p{
      font-size: 0.875rem;
      margin-bottom: 0;
    }
    .container {
      border-top: 1px solid #c4bfc0;
      padding-top: 2rem;
      @include touch {
        border-top: none;
        padding-top: 0;
      }
    }
    a {
      color: $white;
      text-decoration: underline;
      font-weight: 400;
      &:hover {
        color: $white;
        text-decoration: none;
      }
    }
  }
  &.footer__global__resources > .container {
    overflow: hidden;
  }
  .contact {
    &-info {
      position: relative;
      font-family: $acumin-pro;
      font-weight: 600;
      padding-bottom: 3rem;
      @include touch {
        padding-left: 0;
        padding-right: 0;
      }
      @include mobile {
        flex-direction: column;
        align-items: center;
        padding-bottom: 2rem;
      }
      .columns.is-desktop {
        align-items: flex-end;
        height: 100%;
      }
      & > .columns {
        @include mobile {
          display: flex;
        }
      }
      .social-container {
        @include touch {
          display: flex;
          align-items: flex-end;
          & > .columns {
            display: flex;
            align-items: flex-end;
            flex-direction: column;
          }
        }
        @include mobile {
          & > .columns {
            flex-direction: row-reverse;
            .column {
              flex-basis: auto;
            }
          }
        }
      }
      a {
        display: block;
        text-align: left;
        img {
          display: block;
          height: 104px;
          @include touch {
            height: 80px;
          }
        }
      }
      a.purdue-home-button, a.wp-block-button__link.wp-element-button{ 
        display: flex; 
      }
      &__address {
        margin-bottom: 1.5rem;
        @include touch {
          margin-bottom: 1.5rem;
        }
        @include mobile {
          margin-bottom: 1rem;
        }
        a {
          text-decoration: underline;
          font-weight: 400;
          font-size: 0.875rem;
          &:hover {
            color: $white;
            text-decoration: none;
          }
        }
      }
      &__phone {
        a {
          text-decoration: underline;
          color: $boiler-gold;
          &:hover {
            color: $boiler-gold;
            text-decoration: none;
          }
        }
        margin-bottom: 0;
        @include touch {
          margin-bottom: 1.5rem;
        }
        @include mobile {
          margin-bottom: 1rem;
        }
      }
      h2.title {
        margin-bottom: 0.5rem;
      }
      &__social {
        display: flex;
        font-size: 1.375rem;
        display: flex;
        flex-wrap: wrap;
        .navbar-item {
          padding: 0;
          margin: 0;
          display: inline;
          a {
            svg{
              fill: $white;
            }
            &:hover {
              color: $boiler-gold;
              svg{
                fill: $boiler-gold;
              }
            }
          }
          &:not(:last-child) {
            margin-right: 0.8rem;
          }
        }
      }
      &__campuses {
        padding: 0;
      }
    }
  }
  .link-resources {
    @include touch {
      margin: 0;
    }
    & > .column {
      @include touch {
        padding: 0;
        border-top: 1px solid #c4bfc0;
        &:last-child {
          border-bottom: 1px solid #c4bfc0;
        }
      }
    }
  }
}
