// image block
.wp-block-image {
  figcaption {
    display: flex;
    align-items: flex-start;
    padding: 0.5rem 0;
    text-align: left;

    p {
      font-size: 1rem !important;

      span {
        font-size: 0.875rem !important;
        font-family: "United Sans Condensed" !important;
        color: #707070 !important;
        text-transform: uppercase;
        padding-left: 1rem;
      }
    }
  }
  .alignleft {
    padding: 0.5rem 1.5rem 0 0;
    margin-bottom: 0.5rem !important;
    float: left;
    figcaption {
      margin-right: 1.5rem;
    }
    @media (max-width: 414px) {
      float: none;
      padding-right: 0;
      width: 100%;
      figcaption {
        max-width: 100% !important;
        margin-bottom: 2.5rem;
        text-align: center;
        margin-right: 0;
      }
    }
  }
  .alignright {
    padding: 0.5rem 0 0 1.5rem;
    margin-bottom: 0.5rem !important;
    float: right;
    figcaption {
      margin-left: 1.5rem;
    }
    @media (max-width: 414px) {
      float: none;
      padding-left: 0;
      width: 100%;
      figcaption {
        max-width: 100% !important;
        margin-bottom: 2.5rem;
        text-align: center;
        margin-left: 0;
      }
    }
  }
  .aligncenter {
    display: flex !important;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    padding-top: 0.5rem;
    margin-bottom: 0.5rem !important;
    @media (max-width: 414px) {
      figcaption {
        max-width: 100% !important;
        margin-bottom: 2.5rem;
        text-align: center;
      }
    }
  }
}

//table block
.wp-block-table-mobile {
  &:first-child{
    padding-top: 2rem;
  }
  display: none;
  @include touch {
    display: block;
    width: 100%;
  }
  margin-bottom:4rem;
  &:last-of-type{
    margin-bottom: 0;
  }
  font-family: $acumin-pro;
  font-size: 1rem;
  text-align: center;

  .mobile-table-header{
      font-family: $united-sans;
      font-weight: 700;
      text-transform: uppercase;
      line-height: 1;
  }

  
  .table-header {
    border-top: none !important;
    background-color: #000;
   
  }
  .table-body {
    border-top: none !important;
    background-color: #ededed;
    color: #000;
    padding: 0 0.5rem;
    line-height: 1.5;
    &:last-child {
      border-bottom: 1px solid #ededed;
    }
  }
  .table-body:not(.table-header){
    &:first-child{
      font-family: $united-sans;
      font-weight: 700;
      text-transform: uppercase;
    }
    
  }
  .columns.is-mobile{
    margin-left: 0;
    margin-right: 0;
  }
  .table-body{    
    .column{
      align-self: center;
    }
    .column:nth-child(odd){
      text-align: right;
    }
    .column:nth-child(even){
      text-align: left;
    }
  }
  .table-body:nth-child(even){
    background-color: #fff;
  }
  .table-footer {
    border-top:none !important;
    background-color: #fff;
    color: #000;
    font-style: italic;
    padding: 0 1.25rem;
    line-height: 1.5;
    text-align: left;
  }
}

.wp-block-table {
  border-bottom: none !important;
  font-family: $acumin-pro;
  @include touch{
    margin-top: 0 !important;
    margin-bottom: 0 !important;
  }

  table {
    font-size: 1rem;
    text-align: left;
    @include touch {
      display: none;
    }   
    thead {
      border-bottom: none;
      tr {
        th {
          border: none !important;
          background-color: #fff;
          line-height: 1.5;
          font-family: $united-sans;
          text-transform: uppercase;
          font-weight: 700;
          padding: 0.5rem 1.25rem;
          line-height: 22px;
        }
      }
    }
    tbody {
      tr {
        &:nth-child(odd) {
          background-color: #ededed !important;
        }
        &:nth-child(even) {
          background-color: #fff !important;
        }
        td, th{
          vertical-align: middle;
          padding: 0.5rem 1.25rem;
          line-height: 22px;
          border: none !important;
          line-height: 1.5;
          &.has-text-align-right{
            text-align: right;
          }
        }
      }
    }
    tfoot {
      border: none;
      tr {
        td {
          border: none !important;
          background-color: #fff;
          color: #000 !important;
          font-style: italic;
          padding: 1.25rem;
          line-height: 1.5;
          @include touch {
            padding: 0.5rem 1.25rem;
          }
        }
      }
    }
  }

  &.no-collapse{
    table{
      @include touch {
        display: table;
      }
    }
  }
  figcaption {
    font-size: 1.125rem;
    font-style: normal !important;
    text-align: left;
  }
}