/**
 * #.# Editor Styles
 *
 * CSS for just Backend enqueued after style.scss
 * which makes it higher in priority.
 */


 .purdue-home-featured-story-editor{
   .components-button.is-primary{
      position:absolute;
      bottom:1rem;
      left:1rem;
      z-index:10;
   }
}