!function(){const e=()=>{const e=document.querySelectorAll(".purdue-home-layout--left-banner");e.length>0&&e.forEach(e=>{const n=e.querySelector(".purdue-home-layout--left-banner__image img");if(n){const t=n.clientHeight,o=e.clientHeight,i=e.parentElement.offsetTop;if(t<o){const e=Math.round((window.scrollY-i)*(o-t)/(o-window.innerHeight));window.scrollY>=i&&window.scrollY<i+o-window.innerHeight?n.style.transform="translate3d(0px, "+e+"px, 0px)":window.scrollY<=i?n.style.transform="translate3d(0px, 0px, 0px)":window.scrollY>=i+o-window.innerHeight&&(n.style.transform="translate3d(0px, "+(o-t)+"px, 0px)")}}})};let n=!1;window.addEventListener("scroll",()=>{n||(n=!0,setTimeout(function(){e(),n=!1},50))},{passive:!0}),window.addEventListener("load",()=>{e()}),window.addEventListener("resize",()=>{e()})}();