.purdue-home-link-cards .glide__slides{display:flex}.purdue-home-link-cards .glide__slide{padding:.2rem;flex:1;flex:1 0 30%}.purdue-home-link-cards .columns.is-multiline .block-editor-inner-blocks,.purdue-home-link-cards .columns.is-multiline .block-editor-block-list__layout{display:flex;flex-grow:1;flex-wrap:wrap}.purdue-home-link-cards .columns.is-multiline .purdue-home-cta-card .block-editor-inner-blocks,.purdue-home-link-cards .columns.is-multiline .purdue-home-cta-card .block-editor-block-list__layout{display:block}.purdue-home-link-cards ul{padding-left:0}
