!function(){"use strict";var e=window.wp.blocks,a=window.wp.blockEditor;function t(){return t=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var r in t)({}).hasOwnProperty.call(t,r)&&(e[r]=t[r])}return e},t.apply(null,arguments)}function r(){return r=Object.assign?Object.assign.bind():function(e){for(var a=1;a<arguments.length;a++){var t=arguments[a];for(var r in t)({}).hasOwnProperty.call(t,r)&&(e[r]=t[r])}return e},r.apply(null,arguments)}window.wp.data;const c=[["core/paragraph",{placeholder:"Add Card Content"}]],n=["core/paragraph","core/list","core/heading","purdue/button-bar","core/image","core/group"];var s=JSON.parse('{"UU":"purdue/link-cards-single"}');(0,e.registerBlockType)(s.UU,{save:(e,r)=>{const c=a.useBlockProps.save();return React.createElement("div",t({},c,{className:`column is-${e.attributes.columnClass}`}),React.createElement("div",{class:"purdue-home-cta-card purdue-home-cta-card--story"},React.createElement("div",{class:`flex-container flex-container--align-center has-${e.attributes.cardBackground}-background`},React.createElement(a.InnerBlocks.Content,null))))},edit:e=>{const t=(0,a.useBlockProps)(),{className:s,setAttributes:l,context:o}=e,{columnClass:u,cardBackground:i}=e.attributes;let d="",p=o["purdue/link-cards-columns"];return d=3===p?" is-4-desktop is-4-widescreen is-3-fullhd":` is-${p}-desktop`,d+=12!=p?" is-half-tablet":" is-full-tablet",l({columnClass:d,cardBackground:o["purdue/link-cards-cardBackground"]}),[React.createElement("div",r({},t,{className:`column ${u}`}),React.createElement("div",{class:"purdue-home-cta-card purdue-home-cta-card--story"},React.createElement("div",{class:`flex-container flex-container--align-center has-${i}-background`},React.createElement(a.InnerBlocks,{template:c,templateLock:!1,templateInsertUpdatesSelection:!1,allowedBlocks:n}))))]}})}();