.purdue-home-quick-links.purdue-home-quick-links-editor{position:relative;top:0;right:auto;flex-direction:column}.purdue-home-quick-links.purdue-home-quick-links-editor .accordion__heading{flex-direction:row;justify-content:space-between;align-items:center}.purdue-home-quick-links-static .tagged-header-container{margin-bottom:2rem}.purdue-home-quick-links-static .tagged-header-container .tagged-header{font-size:1.125rem}.purdue-home-quick-links-static #quick-links-content{padding-left:0}.purdue-home-quick-links-static #quick-links-content .quick-link__item{border-bottom:2px solid #c4bfc0;padding:.5rem 0}.purdue-home-quick-links-static #quick-links-content .quick-link__item .quick-link__link{color:#000;font-size:1.25rem;font-weight:700;-webkit-text-decoration:none;text-decoration:none}
