.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-layout--left-banner{position:relative;overflow:hidden}.purdue-home-layout--left-banner>.image{position:absolute;top:0;left:0;width:28%;min-height:100%;margin-left:0;padding-left:0 !important;max-width:535px}@media screen and (max-width: 1023px){.purdue-home-layout--left-banner>.image{display:none;padding-left:0}}@media screen and (max-width: 767px){.purdue-home-layout--left-banner>.image{padding-left:0}}.purdue-home-layout--left-banner>.image img{position:relative;min-height:100vh;object-fit:cover;transition:all .1s ease}.purdue-home-layout--left-banner .container{max-width:1152px !important;margin:0}.purdue-home-layout--left-banner>*{margin-left:min(28%,535px);padding-left:5rem !important}@media screen and (max-width: 1023px){.purdue-home-layout--left-banner>*{margin-left:0;padding-left:1.5rem !important}}@media screen and (max-width: 767px){.purdue-home-layout--left-banner>*{padding-left:1.25rem !important}}.purdue-home-layout--left-banner>* .section{padding-left:0}@media screen and (max-width: 1023px){.purdue-home-layout--left-banner>* .section{padding-left:0}}@media screen and (max-width: 767px){.purdue-home-layout--left-banner>* .section{padding-left:0}}.purdue-home-layout--left-banner__header.second-level-page-heading{text-align:left;max-width:765px;margin-bottom:1.25rem}.purdue-home-layout--left-banner__subheader.tagged-header{margin-bottom:2.25rem;margin-left:10px}@media screen and (max-width: 767px){.purdue-home-layout--left-banner__subheader.tagged-header{margin-bottom:2rem}}.purdue-home-layout--left-banner .purdue-home-button-list{justify-content:flex-start;padding-left:0}.purdue-home-layout--left-banner .purdue-home-button-list li:first-child{padding-left:0}.purdue-home-layout--left-banner p.purdue-home-layout--left-banner__subtext{margin-bottom:2.25rem;font-size:1.25rem;max-width:850px}@media screen and (max-width: 767px){.purdue-home-layout--left-banner p.purdue-home-layout--left-banner__subtext{margin-bottom:2rem;font-size:1.25rem}}.purdue-home-layout--left-banner__border hr{margin:0;background:#c4bfc0;box-shadow:0 2px 5px 0 rgba(0,0,0,.15);height:1px}
