!function(){"use strict";var e,t={3619:function(e,t,a){var n=a(6777);function r(e,t=null){if(!e)return;const a=e.querySelector("i"),n=e.classList.contains("cta-play"),r=e.classList.contains("cta-pause"),c=null===t?n:!0===t,l=e.getAttribute("aria-label"),o=e.dataset.toggleLabel;(null===t||c&&n||!c&&r)&&(e.setAttribute("aria-label",o),e.dataset.toggleLabel=l),c?(e.classList.remove("cta-play"),e.classList.add("cta-pause"),a?.classList.add("fa-circle-pause","cta-pause-icon"),a?.classList.remove("fa-circle-play","cta-play-icon")):(e.classList.add("cta-play"),e.classList.remove("cta-pause"),a?.classList.add("fa-circle-play","cta-play-icon"),a?.classList.remove("fa-circle-pause","cta-pause-icon"))}document.addEventListener("DOMContentLoaded",function(){const e=document.querySelectorAll(".purdue-home-cta-card-block__image-container");if(e&&e.length>0)for(let t=0;t<e.length;t++)if(e[t].querySelectorAll(".glide__slide").length>1){let a=new n.A(e[t],{type:"carousel",autoplay:5e3,perView:1,gap:0,keyboard:!1});a.mount({});const c=e[t].querySelector(".cta-btnctrl");c.addEventListener("click",()=>{c.classList.contains("cta-play")?a.enable():a.disable(),r(c)})}})}},a={};function n(e){var r=a[e];if(void 0!==r)return r.exports;var c=a[e]={exports:{}};return t[e](c,c.exports,n),c.exports}n.m=t,e=[],n.O=function(t,a,r,c){if(!a){var l=1/0;for(u=0;u<e.length;u++){a=e[u][0],r=e[u][1],c=e[u][2];for(var o=!0,i=0;i<a.length;i++)(!1&c||l>=c)&&Object.keys(n.O).every(function(e){return n.O[e](a[i])})?a.splice(i--,1):(o=!1,c<l&&(l=c));if(o){e.splice(u--,1);var s=r();void 0!==s&&(t=s)}}return t}c=c||0;for(var u=e.length;u>0&&e[u-1][2]>c;u--)e[u]=e[u-1];e[u]=[a,r,c]},n.d=function(e,t){for(var a in t)n.o(t,a)&&!n.o(e,a)&&Object.defineProperty(e,a,{enumerable:!0,get:t[a]})},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={336:0};n.O.j=function(t){return 0===e[t]};var t=function(t,a){var r,c,l=a[0],o=a[1],i=a[2],s=0;if(l.some(function(t){return 0!==e[t]})){for(r in o)n.o(o,r)&&(n.m[r]=o[r]);if(i)var u=i(n)}for(t&&t(a);s<l.length;s++)c=l[s],n.o(e,c)&&e[c]&&e[c][0](),e[c]=0;return n.O(u)},a=self.webpackChunkpurdue_home_theme=self.webpackChunkpurdue_home_theme||[];a.forEach(t.bind(null,0)),a.push=t.bind(null,a.push.bind(a))}();var r=n.O(void 0,[441],function(){return n(3619)});r=n.O(r)}();