.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.image-buttons{z-index:100;position:absolute;text-align:center;padding-top:1rem;width:100%;bottom:1rem}.purdue-home-cta-strap-preview .purdue-home-cta-strap__container{display:flex;justify-content:space-between;align-items:center;width:100%}.purdue-home-cta-strap-preview ul.purdue-home-button-list{padding-left:0;flex-direction:column}.purdue-home-cta-strap__image .image{display:flex;position:relative;width:60px;height:60px;margin-right:20px}.purdue-home-cta-strap__image .image-buttons{bottom:-1rem;left:0}.purdue-home-cta-strap__image .purdue-home-cta-strap__container{display:flex;justify-content:space-between}.purdue-home-cta-strap__image .purdue-home-cta-strap__container .purdue-home-cta-strap__subTitle{font-weight:900;font-family:acumin-pro,"Franklin Gothic",sans-serif;color:#8e6f3e;line-height:1;margin-bottom:.5rem !important}.purdue-home-cta-strap__image .purdue-home-cta-strap__container .purdue-home-cta-strap__container--left{display:flex}.purdue-home-cta-strap__image .purdue-home-cta-strap__container .purdue-home-cta-strap__container--right{align-content:end;flex-direction:row;flex-wrap:wrap}
