.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.alert-page-widget.modal{z-index:1002 !important;display:flex;transform:translateY(-100%);color:#fff;transition:all .3s ease}.alert-page-widget.modal.is-active{transform:translateY(0)}.alert-page-widget.modal .modal-content{display:flex;flex-direction:column;align-items:center;max-width:650px}.alert-page-widget.modal .modal-content.alert-page__video{max-width:1200px}@media(max-width: 1500px){.alert-page-widget.modal .modal-content.alert-page__video{max-width:900px}}.alert-page-widget.modal .modal-content.alert-page__video .iframe-container{width:100%;margin-bottom:3rem}.alert-page-widget.modal .modal-close{top:3rem}@media screen and (max-width: 1023px){.alert-page-widget.modal .modal-close{right:calc(50% - 20px)}}.alert-page__image{max-width:600px;width:100%;margin-bottom:3rem;border-radius:4px}.alert-page__tag{color:#cfb991;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:.875rem;font-weight:700;letter-spacing:1.67px;text-align:center;margin-bottom:1.5rem}h2.alert-page__header{color:#fff;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-size:3.5rem;font-weight:700;letter-spacing:2.5px;text-align:center;line-height:.9;margin:0 0 1.5rem}@media screen and (max-width: 767px){h2.alert-page__header{font-size:2.5rem}}.alert-page__subtext{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:1.125rem;font-weight:400;letter-spacing:0;text-align:center;margin-bottom:3rem}
