.purdue-home-tabs-horizontal__header{height:auto}.purdue-home-tabs-horizontal__headers{flex-direction:row}.purdue-home-tabs-horizontal .pu-blocks-tabs__panel>.block-editor-inner-blocks{padding:.75rem}.purdue-home-tabs-horizontal .pu-blocks-tabs__panel.active{display:block}
