.page404-header.second-level-page-heading {
  text-align: center;
  max-width: 100%;
}
.page404-desc {
  text-align: center;
  max-width: 800px;
  margin: 0 auto;
}
.page404-quick-links {
  margin-top: 2rem;
}
