#to-top {
  position: fixed;
  bottom: 5rem;
  right: 5rem;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 1.5rem;
  margin: 0;
  transition: transform 0.2s ease;
  z-index: 999;
  border: none;
  background: none;
  flex-direction: column;
  align-items: center;
  &:hover {
    cursor: pointer;
  }
  .icon {
    width: 56px;
    height: 56px;
    padding: 1rem;
    color: $boiler-gold;
    background: black;
    border: 2px solid $boiler-gold;
    border-radius: 100%;
    margin-bottom: 0.5rem;
  }
  &.to-top-hidden {
    transform: translateY(300%);
  }

  &.to-top-shown {
    transform: translateX(0);
  }

  @media (max-width: 414px) {
    font-size: 1.25rem;
    right: 2rem;
    padding: 1.2rem;
  }
}
.to-top-relative {
  position: relative !important;
  float: right;
  margin-bottom: -5rem !important;
  bottom: -6rem !important;
}


@media (prefers-reduced-motion: reduce) { 
  #to-top {
    transition: none;
  }
}