 @import "../../../src/style/front-end/overides/colors";
 @import "../../../src/style/front-end/overides/variables";
 @import '../../../node_modules/bulma/sass/utilities/mixins.sass';
 
 .purdue-color-hero {
    position: relative;
    display: flex;
    flex-direction: column;
    justify-content: center;
    @include tablet {
      min-height: 700px;
    }
  
    .section.has-padding-bottom-large {
      height: 100%;
      @include mobile {
        padding-bottom: 0;
      }
      .container {
        @include mobile {
          padding-bottom: 3rem;
        }
      }
    }
  
    &--body {
      @include tablet {
        width: 55%;
        max-width: 700px;
      }
    }
  
    &--subheader {
      left: 10px;
      margin-bottom: 2.5rem !important;
    }
  
    &--header {
      text-align: left !important;
  
      @include from($tablet) {
        font-size: 4.5rem !important;
      }
  
      @include desktop {
        font-size: 6rem !important;
      }
    }
    &--subtext {
      font-size: 1rem;
      font-family: $acumin-pro;
      @include tablet {
        font-size: 1.25rem;
        line-height: 1.5;
      }
    }
  
    &--stats {
      display: flex;
      flex-direction: column;
      justify-content: center;
      box-shadow: 0 0 0 100vmax #000;
      clip-path: inset(0 -100vmax);
      height: 100%;
      padding: 35px 0;
  
      @include tablet {
        padding: 0;
        box-shadow: none;
        width: 42%;
        position: absolute;
        right: 0;
        top: 0;
        padding: 6.5rem 1.2rem;
      }
  
      @include desktop {
        padding: 3.25rem;
      }
      &-heading {
        font-size: 0.875rem;
        line-height: 1.5;
        text-align: left;
        text-transform: uppercase;
        font-family: $acumin-pro;
        font-weight: 700;
        display: flex;
        align-items: center;
        color: $boiler-gold;
        margin-bottom: 40px;
  
        @include tablet {
          margin-bottom: 51px !important;
        }
  
        &::after {
          content: "";
          flex-grow: 1;
          border-top: 2px solid #cfb991;
          width: 84px;
          position: relative;
          display: flex;
          margin-left: 25px;
        }
      }
  
      &-wrapper {
        display: flex;
        justify-content: space-between;
        width: 100%;
        @include tablet {
          justify-content: auto;
          flex-direction: column;
        }
        &--box {
          width: 50%;
          @include tablet {
            width: 100%;
          }
  
          &:nth-child(1) {
            margin-bottom: 75px;
            @include mobile {
              margin-bottom: 1rem;
              padding-right: 2rem;
            }
          }
          &--stat {
            font-size: 3rem;
            line-height: 0.9;
            font-weight: bold;
            color: #cfb991;
            font-family: $united-sans-condensed;
            text-transform: uppercase;
            display: block;
            @include tablet {
              font-size: 5rem;
              line-height: 1;
            }
  
            @include desktop {
              font-size: 6rem;
              line-height: 1;
            }
  
            @include widescreen {
              font-size: 126px;
              line-height: 0.9;
            }
            @include fullhd {
              font-size: 136px;
              line-height: 0.9;
            }
          }
          &--description,
          &--source {
            font-size: 0.875rem;
            line-height: 1.5;
            font-family: $acumin-pro;
            display: block;
            @include tablet {
              font-size: 1.875rem;
              line-height: 1.3;
            }
          }
          &--source {
            font-style: italic;
            text-transform: capitalize;
            display: block;
          }
          &--description {
            font-weight: 600;
            margin-top: 10px;
          }
          &--source {
            font-weight: 400;
            margin-top: 1rem;
            a {
              color: $white !important;
              &:hover {
                color: $white !important;
              }
            }
          }
        }
      }
    }
    ul.purdue-home-button-list {
      list-style-type: none;
      padding: 0;
      justify-content: flex-start;
      margin-top: 2rem;
      li:first-child {
        padding-left: 0;
      }
    }
  }

