!function(){const e=document.querySelectorAll(".hero-down-arrow"),o=window.innerHeight-80;e&&e.length>0&&e.forEach(e=>{e.addEventListener("click",()=>{window.scroll({top:o,behavior:"smooth"})})});const t=e=>{e.size=e.options.length,e.classList.add("has-select-expand"),e.addEventListener("click",()=>{e.size=1,e.classList.remove("has-select-expand")})};let c=window.location.hash;if(c){c=c.replace("#","");const e=document.getElementById(c);if(e){e.focus();const o=e.querySelector("select");o&&t(o)}}const n=document.querySelectorAll(".purdue-home-link-hero__list--desktop .purdue-home-button"),l=window.location.href.replace(location.hash,"");n.length>0&&n.forEach(e=>{if(e.href.includes(l)){const o=e.href.replace(l,"");o&&e.addEventListener("click",e=>{const c=document.querySelector(o);if(c){const e=c.querySelector("select");e&&t(e)}})}})}();