.gsc-control-cse {
  font-family: $acumin-pro;
  padding: 0 !important;
}
.gsc-above-wrapper-area {
  td {
    padding-left: 0;
    padding-right: 0;
  }
}
.gsc-result-info-container {
  padding-left: 0 !important;
  .gsc-result-info {
    font-size: 0.875rem;
    padding-left: 0;
  }
}
.gsc-orderby-container {
  padding-right: 0 !important;
  .gsc-orderby {
    font-size: 1rem;
    text-align: right;
  }
}
.gs-result .gs-visibleUrl {
  color: $steel-gray !important;
}
.gsc-thumbnail-inside {
  padding-left: 0;
  padding-right: 0;
  .gs-title,
  .gs-title b {
    color: $aged-gold !important;
    font-size: 1.25rem !important;
    font-weight: 600 !important;
  }
}

.gsc-url-top {
  padding: 0.5rem 0 0.3rem;
  font-size: 0.875rem;
  margin-bottom: 0;
}

.gsc-table-result {
  padding-left: 0;
  font-size: 1rem !important;
  line-height: 24px;
}
.gsc-results {
  padding-right: 0;
  width: 100%;
}
.gsc-webResult.gsc-result {
  padding: 1.5rem 0 !important;
  border-bottom: 0.5px solid #c4bfc0;
  border-left: none;
  &:hover {
    border-bottom: 0.5px solid #c4bfc0;
  }
}
.gcsc-more-maybe-branding-root {
  margin-top: 2rem;
}
.gcsc-find-more-on-google {
  color: $aged-gold !important;
  margin-left: 0;
  &:hover {
    text-decoration: none;
  }
}
.gcsc-find-more-on-google-magnifier {
  fill: $aged-gold !important;
}
.gsc-results .gsc-cursor-box {
  margin: 0;
  border-top: none;
  padding-left: 0;
}
.gsc-cursor {
  font-size: 1rem;
  .gsc-cursor-current-page {
    color: #000 !important;
    font-weight: 700;
  }
}
.gcsc-branding {
  padding-right: 0;
}
.gcsc-find-more-on-google-text,
.gcsc-find-more-on-google-query,
.gcsc-branding,
.gcsc-branding-text {
  font-size: 0.875rem;
}
.gs-no-results-result .gs-snippet,
.gs-error-result .gs-snippet {
  border: 1px solid #daaa00;
  background-color: #ebd99f;
}

.search-post {
  padding: 1.5rem 0;
  display: block;
  color: $black;
  &:not(:last-child) {
    border-bottom: 0.5px solid $white;
  }
  &:hover {
    color: $black;
    &:not(:last-child) {
      border-bottom: 0.5px solid #c4bfc0;
    }
  }
  @include mobile {
    &:not(:last-child) {
      border-bottom: 0.5px solid #c4bfc0;
    }
  }
  &-title {
    color: $aged-gold !important;
    font-size: 1.25rem !important;
    font-weight: 600 !important;
    margin-bottom: 0.5rem !important;
  }
  &-link {
    word-break: break-all;
    font-size: 0.875rem;
    color: #555960 !important;
    margin-bottom: 0.875rem !important;
  }
  &-noresult {
    padding-top: 2rem;
    padding-bottom: 2rem;
    font-size: 1.5rem;
    color: $aged-gold;
  }
}
.search-results-count {
  margin-bottom: 1.5rem;
}
.search-results-container {
  border-bottom: 0.5px solid #c4bfc0;
  border-top: 0.5px solid #c4bfc0;
  a{
    text-decoration: none;
  }
}
.search-results-header {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  div {
    margin-bottom: 1rem;
  }
}
.trending-search {
  ul {
    list-style-type: none;
    padding-left: 0;
    li {
      a {
        font-size: 1rem;
        color: $black;
        &:after {
          content: "";
          background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 448 512'%3E%3C!--! Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill='%23000000' d='M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z'/%3E%3C/svg%3E");
          color: $black;
          height: 1.125rem;
          width: 1rem;
          right: -0.25rem;
          margin-left: 0.75rem;
          position: relative;
          font-size: 1.25rem;
          transition: 0.3s ease;
          top: 3px;
          display: inline-block;
        }
        &:hover {
          text-decoration: underline;
          &:after {
            transform: translateX(3px);
          }
        }
      }
    }
  }
}
