.youtube-link-editor{
  padding:1rem 1rem 2rem;
  background:#f3f3f3;
  .youtube-link-form{
    display:flex;
  }
  .youtube-link-input{
    width:100%;
    margin-right:1rem;
  }

}
.tagged-header{
  margin:0;
}
.block-ediotr-field-wrap{
 margin-bottom:0.5rem;
 p{
   font-size: 11px;
   font-weight: 500;
   line-height: 1.4;
   text-transform: uppercase;
   box-sizing: border-box;
   display: block;
   padding-top: 0px;
   padding-bottom: 0px;
   max-width: 100%;
   z-index: 1;
   overflow: hidden;
   text-overflow: ellipsis;
   white-space: nowrap;
   margin-bottom: 0.5rem;
 }
}