.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}@media screen and (max-width: 767px){.purdue-home-image-slider{overflow:hidden}}.purdue-home-image-slider .slider-controls{margin-top:1.5rem}.purdue-home-image-slider .glide{min-height:300px;height:auto}.purdue-home-image-slider .glide figure{max-height:100%}.purdue-home-image-slider .glide figure img.is-16by9{aspect-ratio:16/9}.purdue-home-image-slider .glide figure img{border-radius:4px;object-fit:cover}.purdue-home-image-slider .glide figure figcaption{max-width:min(900px,100% - 16px);width:100%;margin:1.5rem 0 0 1.5rem;padding:0 1.5rem 0 1.5rem;border-left:1px solid #c4bfc0}@media screen and (max-width: 1023px){.purdue-home-image-slider .glide figure figcaption{width:calc(100% - 16px);padding:0 0 0 1rem !important;text-align:left !important}}@media screen and (max-width: 767px){.purdue-home-image-slider .glide figure figcaption{margin:1.5rem 0 0 0 !important}}.purdue-home-image-slider.has-gray-background figcaption{background-color:#ededed}.purdue-home-image-slider.has-white-background figcaption{background-color:#fff}.purdue-home-image-slider.has-black-background figcaption{background-color:#000}.purdue-home-image-slider.has-black-background--dark .glide__bullet{background-color:#000;border:2px solid #fff;opacity:1}.purdue-home-image-slider.has-black-background--dark .glide__bullet--active{background:#fff;opacity:1}.purdue-home-image-slider.has-black-background--dark .glide__bullet--active:hover{background:#fff;opacity:1}.purdue-home-image-slider.has-black-background--dark .glide__bullet:hover{opacity:.7}.purdue-home-image-slider.has-black-background--dark .glide__arrow.arrow--left{margin-right:1rem;background-image:url("data:image/svg+xml,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 448 512%27%3E%3C%21--%21 Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license %28Commercial License%29 Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill=%27%23ffffff%27 d=%27M9.4 233.4c-12.5 12.5-12.5 32.8 0 45.3l160 160c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L109.2 288 416 288c17.7 0 32-14.3 32-32s-14.3-32-32-32l-306.7 0L214.6 118.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0l-160 160z%27/%3E%3C/svg%3E")}.purdue-home-image-slider.has-black-background--dark .glide__arrow.arrow--right{margin-left:1rem;background-image:url("data:image/svg+xml,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 viewBox=%270 0 448 512%27%3E%3C%21--%21 Font Awesome Pro 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license %28Commercial License%29 Copyright 2023 Fonticons, Inc. --%3E%3Cpath fill=%27%23ffffff%27 d=%27M438.6 278.6c12.5-12.5 12.5-32.8 0-45.3l-160-160c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L338.8 224 32 224c-17.7 0-32 14.3-32 32s14.3 32 32 32l306.7 0L233.4 393.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0l160-160z%27/%3E%3C/svg%3E")}.purdue-home-image-slider__card.purdue-home-cta-card{display:flex;cursor:default}@media screen and (max-width: 767px){.purdue-home-image-slider__card.purdue-home-cta-card{flex-direction:column}}.purdue-home-image-slider__card-image{flex:1}@media screen and (max-width: 767px){.purdue-home-image-slider__card-image{width:100%}}.purdue-home-image-slider__card-image .image{min-height:400px}@media screen and (max-width: 767px){.purdue-home-image-slider__card-image .image{min-height:1px}}.purdue-home-image-slider__card-image .image:after{content:none !important}.purdue-home-image-slider__card-title{font-size:2rem;font-weight:700;line-height:1.1}@media screen and (max-width: 1215px){.purdue-home-image-slider__card-title{font-size:1.5rem}}.purdue-home-image-slider__card .flex-container--align-bottom{width:350px;padding:2.5rem;display:flex;flex-direction:column;justify-content:flex-end;align-items:flex-start;height:auto;position:relative}@media screen and (max-width: 767px){.purdue-home-image-slider__card .flex-container--align-bottom{width:100%;padding:2.5rem 1.125rem}}.purdue-home-image-slider--has-text .purdue-home-image-slider__card{flex-wrap:wrap}.purdue-home-image-slider--has-text .slider-controls{margin-top:3rem}@media screen and (max-width: 767px){.purdue-home-image-slider--has-text .slider-controls{margin-top:2rem}}.purdue-home-image-slider .glide-slide{padding:.2rem;display:none}.purdue-home-image-slider .glide__slides .glide__slide:not(.is-active)>*{display:none}
