.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-cta-hero__header-animate.pause *{animation-play-state:paused}@keyframes slideIn{0%{transform:translateX(-100%);opacity:0}100%{transform:translateX(0);opacity:1}}@keyframes slideOut{0%{opacity:1;transform:translateX(0)}100%{opacity:0;transform:translateX(100%)}}.purdue-home-cta-hero .cta-btnctrl{color:#8e6f3e;font-size:2rem;z-index:2;background:none;border:none;cursor:pointer;padding:0;line-height:1}.purdue-home-cta-hero .cta-play.is-active,.purdue-home-cta-hero .cta-pause.is-active{display:block;width:32px;height:32px}.purdue-home-cta-hero .controls{display:flex;width:100%;justify-content:flex-end}.purdue-home-cta-hero .section .container{display:flex;flex-direction:column;align-items:center}.purdue-home-cta-hero .section .container .tagged-header{-ms-grid-row-align:center;align-self:center;margin-bottom:2.5rem}@media screen and (max-width: 767px){.purdue-home-cta-hero .section .container .tagged-header{margin-bottom:2rem}}.purdue-home-cta-hero__header.second-level-page-heading{max-width:950px;margin-bottom:1.875rem;overflow:hidden}@media screen and (max-width: 767px){.purdue-home-cta-hero__header.second-level-page-heading{margin-bottom:1.5rem}}.purdue-home-cta-hero .purdue-home-cta-hero__header-static{position:relative;z-index:1;background:#fff;display:block;width:100%}.purdue-home-cta-hero .purdue-home-cta-hero__header-animate{display:block}.purdue-home-cta-hero .purdue-home-cta-hero__header-animate-item{opacity:0;position:relative;z-index:0;transform:translateX(-100%)}.purdue-home-cta-hero .purdue-home-cta-hero__header-animate-item.slide-in{display:inline-block;transform:translateY(0);opacity:1;animation:slideIn 2s}.purdue-home-cta-hero .purdue-home-cta-hero__header-animate-item.slide-out{display:inline-block;transform:translateX(-100%);opacity:0;animation:slideOut .5s}@keyframes slideOut{0%{opacity:1;transform:translateX(0)}100%{opacity:0;transform:translateX(100%)}}.purdue-home-cta-hero .purdue-home-cta-hero .controls{display:flex;width:100%;justify-content:flex-end}.purdue-home-cta-hero__content{max-width:685px;font-size:1.25rem}@media screen and (max-width: 767px){.purdue-home-cta-hero__content{font-size:1rem}}.purdue-home-cta-hero__content p{text-align:center;font-size:inherit}.purdue-home-cta-hero__cards{margin-top:4rem;width:100%}@media screen and (max-width: 767px){.purdue-home-cta-hero__cards{margin-top:2.5rem}}.purdue-home-cta-hero .pudue-home-cta-card{position:relative}.purdue-home-cta-hero .purdue-home-cta-card *{z-index:1}.purdue-home-cta-hero .purdue-home-cta-card * image:after{content:none}.purdue-home-cta-hero__card-title{display:block;top:0;right:0;bottom:0;left:0;z-index:10 !important;-webkit-text-decoration:none;text-decoration:none}.purdue-home-cta-hero__card-title p{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:3.875rem;font-weight:700;letter-spacing:0;line-height:.9;text-shadow:3px 3px 4px rgba(0,0,0,.25);margin-bottom:1.875rem}.purdue-home-cta-hero__card-title:after{content:"";position:absolute;top:0;right:0;bottom:0;left:0;z-index:10;pointer-events:auto}@media screen and (max-width: 1215px){.purdue-home-cta-hero__card-title{font-size:2.5rem;margin-bottom:.8rem !important}}@media screen and (max-width: 1023px){.purdue-home-cta-hero__card-title{font-size:2rem;margin-bottom:.8rem !important}}@media screen and (max-width: 767px){.purdue-home-cta-hero__card-title{font-size:2.5rem;margin-bottom:.8rem !important}}.purdue-home-cta-hero__card-subtext{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:1.25rem;font-weight:400;letter-spacing:0;line-height:1.5;text-shadow:3px 3px 4px rgba(0,0,0,.25)}@media screen and (max-width: 1023px){.purdue-home-cta-hero__card-subtext{font-size:1rem}}.purdue-home-cta-hero ul.purdue-home-button-list{margin-top:2.5rem;padding-left:0}.purdue-home-cta-hero .purdue-home-cta-card.has-content-bottom .image:after{z-index:1;background-color:rgba(0,0,0,.55) !important}.purdue-home-cta-hero .purdue-home-cta-card.has-content-bottom:after{z-index:1;pointer-events:none}
