.purdue-home-tabs__header{height:auto}.purdue-home-tabs__headers.vertical{flex-direction:column}.purdue-home-tabs .pu-blocks-tabs__panel>.block-editor-inner-blocks{padding:.75rem}.purdue-home-tabs .pu-blocks-tabs__panel.active{display:block}
