<?php return array(
    'root' => array(
        'name' => 'purdue/purdue-home-theme',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => '7a228cc1cf5a1a689875a170aaa2571b059541f9',
        'type' => 'wordpress-theme',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'purdue/boilerup-wp' => array(
            'pretty_version' => '1.8.5',
            'version' => '1.8.5.0',
            'reference' => '1d20b3fbb28581c900797f321469a45696736ac4',
            'type' => 'wordpress-muplugin',
            'install_path' => __DIR__ . '/../purdue/boilerup-wp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'purdue/purdue-home-theme' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => '7a228cc1cf5a1a689875a170aaa2571b059541f9',
            'type' => 'wordpress-theme',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
