!function(){"use strict";var e=window.wp.blocks,t=window.wp.blockEditor;function a(){return a=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var r in a)({}).hasOwnProperty.call(a,r)&&(e[r]=a[r])}return e},a.apply(null,arguments)}var r=window.wp.components;function n(){return n=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var r in a)({}).hasOwnProperty.call(a,r)&&(e[r]=a[r])}return e},n.apply(null,arguments)}const l=[["core/paragraph",{placeholder:"Add tab content"}]];var i=JSON.parse('{"UU":"purdue/tab-horizontal-block"}');function o(){return o=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var a=arguments[t];for(var r in a)({}).hasOwnProperty.call(a,r)&&(e[r]=a[r])}return e},o.apply(null,arguments)}var c=[{supports:{className:!1},save:e=>React.createElement("div",o({className:"purdue-home-tabs-horizontal__panel"+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},e.attributes.id?{"data-name":e.attributes.id}:{}),React.createElement(t.InnerBlocks.Content,null))},{save:e=>React.createElement("div",{className:"purdue-home-tabs-horizontal__panel"+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},React.createElement(t.InnerBlocks.Content,null))}];(0,e.registerBlockType)(i.UU,{save:e=>React.createElement("div",a({className:"purdue-home-tabs-horizontal__panel"+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},e.attributes.id?{"data-name":e.attributes.id}:{}),React.createElement(t.InnerBlocks.Content,null)),edit:e=>{const a=(0,t.useBlockProps)();return[React.createElement(t.InspectorControls,{key:"1"},React.createElement(r.PanelBody,null,React.createElement(r.PanelRow,null,React.createElement(r.TextControl,{label:"HTML Anchor",help:"Enter a word without spaces to make a unique web address just for this block, called an “anchor.” It must be unique from any other anchors on the page. Then, you’ll be able to link directly to this section of your page.",value:e.attributes.id,onChange:t=>e.setAttributes({id:t})})))),React.createElement("div",a,React.createElement("div",n({className:"purdue-home-tabs-horizontal__panel "+(e.attributes.editorSelected?" active":""),"aria-labelledby":`header-${e.attributes.aria}`,id:`panel-${e.attributes.aria}`},e.attributes.id?{"data-name":e.attributes.id}:{}),React.createElement(t.InnerBlocks,{template:l,templateLock:!1,templateInsertUpdatesSelection:!1})))]},deprecated:c})}();