.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-color-hero .purdue-color-hero--stats-wrapper--box{margin-bottom:2rem}.purdue-home-color-hero--right__stat{font-size:100px;font-weight:bold;color:#cfb991;font-family:"United Sans",Impact,"Arial Black","sans serif";margin:0;line-height:.9;display:block}.purdue-home-color-hero--right__description{color:#fff;font-size:29px;line-height:38px;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-weight:900;text-transform:uppercase;display:block}.purdue-home-color-hero--right__source{color:#fff;font-size:29px;line-height:38px;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-weight:500;text-transform:uppercase;display:block}.purdue-home-color-hero--right__source a{color:#fff}.purdue-home-color-hero ul.purdue-home-button-list{list-style-type:none;padding:0;justify-content:flex-start;margin-top:2rem}
