.purdue-home-cta-banner {
  position: relative;
  .purdue-home-cta-banner__subheader {
    color: $white;
  }
  .image {
    display: block;
    position: absolute;
    width: 100%;
    height: 100%;
    overflow: hidden;
    &:after {
      content: "";
      position: absolute;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.55);
    }
    img,
    video {
      object-position: center;
      object-fit: cover;
      width: 100%;
      height: 100%;
    }


    img {
      &.background-top {
        object-position: top;
      }
      &.background-bottom {
        object-position: bottom;
      }
    }


  }
  &__subheader {
    color: $white;
  }
  &__header {
    color: $white;
    font-family: $acumin-pro;
    font-size: 4rem;
    font-weight: 700;
    letter-spacing: 0;
    line-height: 1;
    text-align: center;
    margin: 1.5rem auto 2.5rem !important;
    max-width: 650px;
    @include mobile {
      font-size: 3rem;
      line-height: 1.2;
    }
    &.font-size-small {
      font-size: 2.125rem;
      line-height: 1.25;
      @include mobile {
        font-size: 1.8rem;
        line-height: 1.4;
      }
    }
    &.font-size-medium {
      font-size: 3em;
      line-height: 1.2;
      @include mobile {
        font-size: 1.8rem;
        line-height: 1.4;
      }
    }
  }
  ul.purdue-home-button-list {
    padding-left: 0;
    li {
      width: auto;
      &.purdue-home-button-wrap--full {
        width: 100%;
        margin-bottom: 15px;
        .purdue-home-button {
          font-size: 1.25rem;
          padding-top: 0.75rem;
          padding-bottom: 0.75rem;
          max-width: 300px;
        }
      }
      .purdue-home-button {
        @media (max-width: 500px) {
          min-width: 278px;
        }
      }
    }
  }
  button {
    cursor: pointer;
  }
}


.purdue-home-cta-banner{

  &.purdue-home-rtb-hero{   

    .purdue-home-slider--rtb-hero{

      .image{
        position: relative;
      }

    }
    

  }

}