blockquote {
  padding: 3rem 0;
  p {
    font-family: $acumin-pro;
    font-size: 1.75rem;
    font-style: normal;
    font-weight: 700;
    line-height: 1.21;
    margin-bottom: 1.5rem !important;
    @include mobile {
      font-size: 1.625rem;
    }
    &:first-child{
      &:before{
        content: "“";
      }
    }
    &:last-of-type{
      &:after{
        content: "”";
      }
    }
  }

  cite {
    font-size: 1rem;
    font-style: normal;
    font-weight: 700;
    line-height: 1.56;
    letter-spacing: 0.1rem;
    text-transform: uppercase;
    font-family: $acumin-pro-condensed;
    margin-bottom: 0 !important;
  }
}
