.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-video-embed .tagged-header-container{margin-bottom:2rem}@media screen and (max-width: 767px){.purdue-home-video-embed .tagged-header-container{margin-bottom:1.5rem}}.purdue-home-video-embed .section.has-black-background .tagged-header-container{border-color:#cfb991}.purdue-home-video-embed .section.has-black-background .tagged-header-container .tagged-header{background:#cfb991;color:#000}.purdue-home-video-embed .container.is-9by16{max-width:422px;max-height:750px}.purdue-home-video-embed .container.is-9by16 .iframe-container{padding-top:177.7777%}@media screen and (min-width: 768px),print{.purdue-home-video-embed .purdue-home-cta-card .cta-link{font-size:2.25rem;margin-bottom:.5rem}}@media screen and (min-width: 1024px){.purdue-home-video-embed .purdue-home-cta-card .cta-link{font-size:3.25rem;margin-bottom:1rem}}@media screen and (min-width: 768px),print{.purdue-home-video-embed .purdue-home-cta-card .cta-icon.cta-icon--play{width:80px;height:80px}}@media screen and (min-width: 1024px){.purdue-home-video-embed .purdue-home-cta-card .cta-icon.cta-icon--play{width:90px;height:90px}}.purdue-home-video-embed .playbtn{display:flex;flex-direction:column;justify-content:center;align-items:center;background:rgba(0,0,0,0);border:rgba(0,0,0,0)}
