.purdue-home-callout {
  font-size: 1em;
  line-height: 1;
  position: relative;
  max-width: 1112px;
  margin-left: 0;
  margin-right: -556px;
  &:before{
    pointer-events: none;
    user-select: none;
    content: "";
    clear: both;
    display: table;
    margin: 0;
  }
  @include until-fullhd{
    max-width: 100vw;
    margin-left: 0;
    margin-right: calc(-50vw - -50%);
    padding-right: 16px;
  }
  .callout-wrapper{
    margin-left: 2rem;
    margin-bottom: 0.875rem;
    width: 318px;
    float: right;
    display: block;
    position: relative;
    margin-top: 0.5rem;
    @include mobile{
      width: 100%;
      margin-left: 0;
      margin-top: 0;
      padding-left: 0;
      margin-bottom:2rem;
    }
    figure{
      margin:0;
    }
    .iframe-container{
      border-radius: 4px;
      overflow: hidden;
      &.vimeo-video-container{
        padding-top:56.25%;
        &.is-square{
          padding-top:100%;
        }
        &.is-9by16{
          padding-top:177.8%;
        }
        &.is-21by9{
          padding-top:42.86%;
        }
        position:relative;
        iframe{
          width: 100%;
          height: 100%;
          position: absolute;
          top:0;
          left:0;
        }
      }

    }
    .callout__text{
      margin:1.5rem 1.5rem 2rem;
      padding-left:1.5rem;
      border-left: 1px solid $steam-gray;
      white-space: pre-line;
      line-height:1.5;
      color:$steel-gray;
      &:last-child{
        margin-bottom: 0;
      }
      @include mobile{
        margin-left:0;
        padding-left:1rem;
      }
    }
    &:not(.has-link){
      figure img{
        border-radius: 4px;
      }
    }
    &.has-link{
      box-shadow: 0px 2px 4px 0px rgba(0, 0, 0, 0.25);
      border-radius: 4px;
      overflow:hidden;
      text-decoration: none;
      figure img{
        border-radius: 0;
      }
      .callout__text{
        font-family: $acumin-pro;
        font-size: 1.25rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1.4;
        margin:1.5rem 1rem 2rem;
        text-decoration: none;
        color:$black;
        border-left:none;
        padding:0;
      }
      .cta-link{
        font-family: $united-sans-condensed;
        font-size: 1.125rem;
        font-style: normal;
        font-weight: 700;
        line-height: 1.22;
        letter-spacing: 2px;
        margin:0 1rem 1.5rem;
        padding:0;
        display:inline-block;
        color:$black;
        &:after{
          border: 1px solid $aged-gold;
          background: $aged-gold;
        }
      }
      &:hover{
        .cta-link:after{
          visibility: visible;
          transform: scaleX(1);
        }
      }
    }
    
  }
  &>p{
    font-size: 1em;
    text-align: left;
    margin-bottom: 1.875rem;
  
  }
  & + *:not(p){
    clear:both;
  }
}
