window.addEventListener("load",function(){const e=document.querySelector(".alert-page-widget");if(e){const t=document.querySelector(".show-multiple-times");if(!localStorage.getItem("seenModal")||t){const e=document.querySelector(".alert-page-widget");e&&(e.classList.add("is-active"),localStorage.setItem("seenModal","true"))}const o=e.querySelector(".alert-page__link");o&&/\/#$/.test(o.href)&&o.addEventListener("click",t=>{t.preventDefault(),e.classList.remove("is-active")})}});