.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-two-column-cta__cards{width:100%;display:flex;flex-wrap:wrap}.purdue-home-two-column-cta__cards .purdue-home-cta-card{width:50%;border-radius:0}@media screen and (max-width: 767px){.purdue-home-two-column-cta__cards .purdue-home-cta-card{width:100%}}.purdue-home-two-column-cta__cards .purdue-home-cta-card .image{min-height:880px}@media screen and (max-width: 767px){.purdue-home-two-column-cta__cards .purdue-home-cta-card .image{min-height:0px}}.purdue-home-two-column-cta__cards .purdue-home-cta-card .image:after{background:none}.purdue-home-two-column-cta__cards .purdue-home-cta-card .image img{width:100%;height:100%;border-radius:0}.purdue-home-two-column-cta__cards .flex-container--align-center{position:absolute !important;display:flex !important;flex-direction:column !important;padding:2rem !important;background:#fff !important;width:auto !important;height:auto !important;bottom:2.25rem !important;max-width:530px !important;top:auto !important;justify-content:flex-start !important;border-radius:4px}.purdue-home-two-column-cta__cards .flex-container--align-center .purdue-home-button{margin-top:auto}@media screen and (max-width: 767px){.purdue-home-two-column-cta__cards .flex-container--align-center{position:relative !important;bottom:auto !important;top:-100px !important;min-height:0px !important;padding:3rem 1.25rem !important;max-width:100% !important}}.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical{box-shadow:none;margin-bottom:0;position:relative}@media screen and (max-width: 767px){.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical{margin-bottom:-100px}}.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center{align-items:flex-end;right:2.25rem;left:auto;justify-content:flex-end;margin-left:2.25rem}@media screen and (max-width: 767px){.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center{right:auto;left:auto;margin-left:1.25rem;margin-right:1.25rem;justify-content:center;align-items:center}}.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center p,.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center h2{text-align:right}@media screen and (max-width: 767px){.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center p,.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:first-child .flex-container--align-center h2{text-align:center}}.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:last-child .flex-container--align-center{align-items:flex-start;left:2.25rem;margin-right:2.25rem}@media screen and (max-width: 767px){.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:last-child .flex-container--align-center{right:auto;left:auto;margin-left:1.25rem;margin-right:1.25rem;justify-content:center;align-items:center}}@media screen and (max-width: 767px){.purdue-home-two-column-cta .purdue-home-cta-card.purdue-home-cta-card--vertical:last-child .flex-container--align-center p{text-align:center}}.purdue-home-two-column-cta__card-title:not(:last-child){color:#000;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:2.5rem;font-weight:700;letter-spacing:0;line-height:1.1;margin-bottom:1.5rem !important}@media screen and (max-width: 767px){.purdue-home-two-column-cta__card-title:not(:last-child){font-size:2rem;margin-bottom:1.2rem !important}}.purdue-home-two-column-cta__card-subtext{color:#000;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:1rem;font-weight:400;letter-spacing:0;line-height:1.5}
