/**
 * #.# Editor Styles
 *
 * CSS for just Backend enqueued after style.scss
 * which makes it higher in priority.
 */


.purdue-home-cta-banner {
    .image-buttons {
        z-index: 100;
        position: absolute;
        text-align:center;
        padding-top:1rem;
        width:100%;
        bottom:1rem;
    }
}