.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}:root{--animationSpeed1: 40;--animationSpeed2: 40;--translate1: calc(-284px * 8);--translate2: calc(-284px * 8);--translateStart: 0}@keyframes scroll1{0%{transform:translateX(0);transform:translateX(var(--translateStart))}100%{transform:translateX(calc(-284px * 8));transform:translateX(var(--translate1))}}@keyframes scroll2{0%{transform:translateX(0);transform:translateX(var(--translateStart))}100%{transform:translateX(calc(-284px * 8));transform:translateX(var(--translate2))}}@keyframes bounce{0%,20%,50%,80%,100%{transform:translateY(0)}40%{transform:translateY(-15px)}60%{transform:translateY(-5px)}}.continuous-moving-slider{background:none;margin:auto;position:relative;width:100%;overflow:hidden;padding-bottom:.75rem}.continuous-moving-slider .slide-track{animation:scroll1 calc(40*1s) linear infinite;animation:scroll1 calc(var(--animationSpeed1)*1s) linear infinite;display:flex;width:auto}@media screen and (max-width: 767px){.continuous-moving-slider .slide-track{animation:none}}.continuous-moving-slider.row-2 .slide-track{position:relative;animation:scroll2 calc(40*1s) linear infinite;animation:scroll2 calc(var(--animationSpeed2)*1s) linear infinite;left:-138px}@media screen and (max-width: 767px){.continuous-moving-slider.row-2 .slide-track{left:-69px;animation:none}}.continuous-moving-slider .slide{height:153px;width:276px;border-radius:2px;box-shadow:2px 4px 5px -1px rgba(0,0,0,.3);flex:0 0 auto;position:relative;margin:0 .25rem}@media screen and (max-width: 767px){.continuous-moving-slider .slide{height:153px;width:calc(33.3% - 2.67px);height:calc(18.73vw - 1.5px);margin:0 .125rem}}.continuous-moving-slider .slide>*{max-width:100%;object-fit:cover;position:absolute;width:100%;height:100%;top:0;left:0;min-height:0;object-position:center}@media screen and (min-width: 1216px)and (min-height: 900px){.purdue-home-canopy-hero{height:calc(100vh - 91px);max-height:900px}}.purdue-home-canopy-hero__canopy{position:relative}@media screen and (max-width: 767px){.purdue-home-canopy-hero .section{padding-top:2rem;padding-bottom:2rem}}.purdue-home-canopy-hero h1{font-size:8.75rem;line-height:.9;text-align:center;font-weight:700;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";text-transform:uppercase}@media screen and (max-width: 1407px){.purdue-home-canopy-hero h1{font-size:8rem}}@media screen and (max-width: 1215px){.purdue-home-canopy-hero h1{font-size:6.5rem;max-width:850px;margin-left:auto;margin-right:auto}}@media screen and (max-width: 1023px){.purdue-home-canopy-hero h1{font-size:5rem;max-width:600px}}@media screen and (max-width: 767px){.purdue-home-canopy-hero h1{font-size:3.5rem;margin-bottom:2rem}}.purdue-home-canopy-hero__links{display:flex;flex-direction:row;align-items:center;justify-content:center;color:#555960;flex-wrap:wrap}.purdue-home-canopy-hero__links span{text-transform:uppercase;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-weight:900;letter-spacing:1.75px;font-size:1rem;padding-bottom:.5rem}@media screen and (max-width: 767px){.purdue-home-canopy-hero__links ul{padding-left:0}}.purdue-home-canopy-hero .hero-down-arrow{display:flex;justify-content:center}.purdue-home-canopy-hero .hero-down-arrow>*{position:relative;color:#8e6f3e;margin-top:3rem;font-size:2rem;cursor:pointer;animation-name:bounce;animation-duration:2s;animation-iteration-count:2;animation-fill-mode:forwards}.purdue-home-canopy-hero .hero-down-arrow>*:hover,.purdue-home-canopy-hero .hero-down-arrow>*:focus{opacity:.9;animation:none}@media(max-width: 1199px){.purdue-home-canopy-hero .hero-down-arrow>*{width:35px}}@media(max-width: 767px){.purdue-home-canopy-hero .hero-down-arrow>*{margin-top:1.75rem}}@media(prefers-reduced-motion: reduce){.purdue-home-canopy-hero .hero-down-arrow{animation-play-state:paused !important}}.purdue-home-canopy-hero .cta-play,.purdue-home-canopy-hero .cta-pause{color:#8e6f3e;font-size:2rem;position:absolute;bottom:-2rem;right:1rem;z-index:2;background:none;border:none;cursor:pointer;padding:0;line-height:1}.purdue-home-canopy-hero .cta-play.is-active,.purdue-home-canopy-hero .cta-pause.is-active{display:block;width:32px;height:32px}@media screen and (max-width: 767px){.purdue-home-canopy-hero .cta-play.is-active,.purdue-home-canopy-hero .cta-pause.is-active{display:none}}
