.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-teritary-hero .section .container{display:flex;flex-direction:column;align-items:center}.purdue-home-teritary-hero__header.second-level-page-heading{max-width:950px;margin-bottom:1.875rem;overflow:hidden}@media screen and (max-width: 767px){.purdue-home-teritary-hero__header.second-level-page-heading{margin-bottom:1.5rem}}.purdue-home-teritary-hero__content{max-width:950px;font-size:1.25rem}@media screen and (max-width: 767px){.purdue-home-teritary-hero__content{font-size:1rem}}.purdue-home-teritary-hero__content p{text-align:center;font-size:inherit;font-weight:500}.purdue-home-teritary-hero__cards{margin-top:4rem;width:100%}@media screen and (max-width: 767px){.purdue-home-teritary-hero__cards{margin-top:2.5rem}}.purdue-home-teritary-hero__cards .purdue-home-cta-card .image img{transition:.3s ease}.purdue-home-teritary-hero__cards .purdue-home-cta-card .image:after{background:linear-gradient(180deg, rgba(0, 0, 0, 0) 0%, #000000 100%)}.purdue-home-teritary-hero__cards .flex-container--align-bottom{position:absolute;top:0;left:0;width:100%;height:100%;display:flex;flex-direction:column;justify-content:flex-end;padding:2.25rem 7rem 2.25rem 3.25rem}@media screen and (max-width: 1023px){.purdue-home-teritary-hero__cards .flex-container--align-bottom{padding:1rem 4.25rem 1rem 1.5rem}}.purdue-home-teritary-hero__cards .flex-container--align-bottom:after{content:"";background-image:url("data:image/svg+xml,%3C%3Fxml version=%271.0%27 encoding=%27UTF-8%27%3F%3E%3Csvg width=%27104.253572px%27 height=%27104.253572px%27 viewBox=%270 0 104.253572 104.253572%27 version=%271.1%27 xmlns=%27http://www.w3.org/2000/svg%27 xmlns:xlink=%27http://www.w3.org/1999/xlink%27%3E%3Ctitle%3Earrow_circle_icon%3C/title%3E%3Cg id=%27Desktop%27 stroke=%27none%27 stroke-width=%271%27 fill=%27none%27 fill-rule=%27evenodd%27%3E%3Cg id=%27arrow_circle_icon%27 transform=%27translate%2852.1268, 52.1268%29 rotate%2840%29 translate%28-52.1268, -52.1268%29translate%2815.1268, 15.1268%29%27 stroke=%27%23cfb991%27 stroke-width=%274%27%3E%3Cg id=%27Group-3%27 transform=%27translate%280, 0%29%27%3E%3Ccircle id=%27Oval-Copy%27 transform=%27translate%2837, 37%29 rotate%28135%29 translate%28-37, -37%29%27 cx=%2736.9999977%27 cy=%2736.9999977%27 r=%2725.1629493%27%3E%3C/circle%3E%3Cg id=%27Arrow-Copy-3%27 transform=%27translate%2827.7199, 21.7701%29%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3E%3Cline x1=%279.52771771%27 y1=%272.99227577%27 x2=%279.56560625%27 y2=%2727.0777404%27 id=%27Path-6%27 transform=%27translate%289.5467, 15.035%29 rotate%2850%29 translate%28-9.5467, -15.035%29%27%3E%3C/line%3E%3Cpolyline id=%27Path-5%27 transform=%27translate%2814.2315, 11.1834%29 rotate%2850%29 translate%28-14.2315, -11.1834%29%27 points=%274.73086087 17.2295253 14.1515077 5.10747085 23.7320575 17.2593992%27%3E%3C/polyline%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/svg%3E");height:90px;width:90px;background-repeat:no-repeat;background-size:cover;right:0;position:absolute;bottom:0;transition:.3s ease}@media screen and (max-width: 767px){.purdue-home-teritary-hero__cards .flex-container--align-bottom:after{height:70px;width:70px}}.purdue-home-teritary-hero__card-title{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:3.875rem;font-weight:700;letter-spacing:0;line-height:.9}@media screen and (max-width: 1215px){.purdue-home-teritary-hero__card-title{font-size:2.5rem;margin-bottom:.8rem !important}}@media screen and (max-width: 1023px){.purdue-home-teritary-hero__card-title{font-size:2rem;margin-bottom:.8rem !important}}@media screen and (max-width: 767px){.purdue-home-teritary-hero__card-title{font-size:2.5rem;margin-bottom:.8rem !important}}.purdue-home-teritary-hero__card-subtext{color:#fff;font-family:acumin-pro,"Franklin Gothic",sans-serif;font-size:1.25rem;font-weight:400;letter-spacing:0;line-height:1.5}@media screen and (max-width: 1023px){.purdue-home-teritary-hero__card-subtext{font-size:1rem}}.purdue-home-teritary-hero .purdue-home-cta-card:hover .image img{scale:1.1}.purdue-home-teritary-hero .purdue-home-cta-card:hover .flex-container--align-bottom:after{transform:translateX(3px)}.purdue-home-teritary-hero ul.purdue-home-button-list{margin-top:2.5rem;padding-left:0}
