.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-quick-links{background:#000;border:1px solid #cfb991;position:fixed;width:auto;right:0;top:50%;z-index:999;display:flex}@media screen and (max-width: 767px){.purdue-home-quick-links{position:relative;top:0;right:auto;flex-direction:column}}.purdue-home-quick-links .accordion__heading{background:none;border:none;padding:1rem;position:relative;display:flex;flex-direction:column-reverse;justify-content:center;align-items:center;color:#cfb991}@media screen and (max-width: 767px){.purdue-home-quick-links .accordion__heading{flex-direction:row;justify-content:space-between;align-items:center}}.purdue-home-quick-links .accordion__heading span{-ms-writing-mode:tb-rl;writing-mode:vertical-rl;transform:scale(-1);color:#cfb991;font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-weight:700;font-size:1.75rem;pointer-events:none;text-transform:uppercase;padding-bottom:1rem}@media screen and (max-width: 767px){.purdue-home-quick-links .accordion__heading span{-ms-writing-mode:initial;writing-mode:initial;font-size:1.5rem;transform:none;padding-bottom:0}}.purdue-home-quick-links .accordion__heading{cursor:pointer}.purdue-home-quick-links .accordion__heading:after{content:"";background-image:url("data:image/svg+xml,%3C%3Fxml version=%271.0%27 encoding=%27UTF-8%27%3F%3E%3Csvg width=%2773.5391052px%27 height=%2773.5391052px%27 viewBox=%270 0 73.5391052 73.5391052%27 version=%271.1%27 xmlns=%27http://www.w3.org/2000/svg%27 xmlns:xlink=%27http://www.w3.org/1999/xlink%27%3E%3Ctitle%3Eclose_icon_circle%3C/title%3E%3Cg stroke=%27none%27 stroke-width=%271%27 fill=%27none%27 fill-rule=%27evenodd%27%3E%3Cg transform=%27translate%2836.7696, 36.7696%29 rotate%28-315%29 translate%28-36.7696, -36.7696%29translate%2810.7696, 10.7696%29%27 stroke=%27%23cfb991%27 stroke-width=%274%27%3E%3Ccircle cx=%2726%27 cy=%2726%27 r=%2724%27%3E%3C/circle%3E%3Cline x1=%2726.5%27 y1=%2714%27 x2=%2726.5%27 y2=%2738%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27%3E%3C/line%3E%3Cline x1=%2725.6896552%27 y1=%2714.5116279%27 x2=%2725.6896552%27 y2=%2738.6976744%27 stroke-linecap=%27round%27 stroke-linejoin=%27round%27 transform=%27translate%2825.6897, 26.6047%29 rotate%28-90%29 translate%28-25.6897, -26.6047%29%27%3E%3C/line%3E%3C/g%3E%3C/g%3E%3C/svg%3E");transition:all .3s ease;width:2.2rem;height:2.2rem;display:block;position:relative;background-size:cover;transform:rotate(-45deg)}.purdue-home-quick-links .accordion__heading.is-open:after{content:"";transform:rotate(0)}.purdue-home-quick-links .accordion__content.navbar-find-info__items{padding:1rem 3rem 0 1rem;width:auto;flex-direction:column;justify-content:space-around}.purdue-home-quick-links .accordion__content.navbar-find-info__items.show{display:flex}.purdue-home-quick-links-static{margin-top:3rem;margin-bottom:3rem;padding-left:3rem;padding-right:3rem}@media screen and (max-width: 1023px){.purdue-home-quick-links-static{padding-left:2rem;padding-right:2rem}}@media screen and (max-width: 767px){.purdue-home-quick-links-static{margin-top:2rem;margin-bottom:2rem;padding-left:0;padding-right:0}}.purdue-home-quick-links-static .tagged-header-container{margin-bottom:2rem}@media screen and (max-width: 767px){.purdue-home-quick-links-static .tagged-header-container{margin-bottom:1.5rem}}.purdue-home-quick-links-static .quick-links-content{padding-left:0;padding-bottom:0;list-style-type:none}.purdue-home-quick-links-static .quick-links-content .quick-link__item{border-bottom:2px solid #c4bfc0;padding-bottom:1.5rem}@media screen and (max-width: 767px){.purdue-home-quick-links-static .quick-links-content .quick-link__item{padding-bottom:.5rem}}.purdue-home-quick-links-static .quick-links-content .quick-link__item:not(:first-child){padding-top:1.5rem}@media screen and (max-width: 767px){.purdue-home-quick-links-static .quick-links-content .quick-link__item:not(:first-child){padding-top:.5rem}}.purdue-home-quick-links-static .quick-links-content .quick-link__item .quick-link__link{color:#000;font-size:1.25rem;font-weight:700;-webkit-text-decoration:none;text-decoration:none}.purdue-home-quick-links-static .quick-links-content .quick-link__item .quick-link__link:hover{-webkit-text-decoration:underline;text-decoration:underline}
