.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.box{border-radius:4px !important}@media(prefers-reduced-motion: reduce){html{scroll-behavior:auto}}@media(prefers-reduced-motion: no-preference){html{scroll-behavior:smooth}}.purdue-home-intro-text .purdue-home-intro-text__header,.purdue-home-intro-text .purdue-home-subheader{text-transform:none}.purdue-home-intro-text .purdue-home-subheader{margin-bottom:1.5rem}.purdue-home-intro-text .has-black-background .purdue-home-subheader{color:#cfb991}.purdue-home-intro-text .has-black-background .purdue-home-intro-text__header{color:#fff}.purdue-home-intro-text .has-gold-background .tagged-header-container{border-color:#000}.purdue-home-intro-text .section .container .columns .column:first-child{border-right:none}.purdue-home-intro-text.has-layout-one-centered .section .container{max-width:880px;text-align:center}.purdue-home-intro-text.has-layout-one-centered .section .container .columns{display:block}.purdue-home-intro-text.has-layout-one-centered .section .container .purdue-home-intro-text__list{justify-content:center}.purdue-home-intro-text.has-layout-one-left .section .container .purdue-home-subheader{text-align:left}.purdue-home-intro-text.has-layout-one-left .section .container .columns{display:block}.purdue-home-intro-text.has-layout-two .section .container .columns{justify-content:space-between;align-items:center}.purdue-home-intro-text.has-layout-two .section .container .columns .column{flex-basis:40%;flex-grow:0}.purdue-home-intro-text.has-layout-two .section .container .purdue-home-subheader{text-align:left}.purdue-home-intro-text.has-layout-two-line .section .container .columns{justify-content:space-between;align-items:center;position:relative}.purdue-home-intro-text.has-layout-two-line .section .container .columns:after{content:"";border-top:4px solid #cfb991;height:4px;width:16%;position:absolute;top:calc(50% - 2px);left:50%;transform:translateX(-50%)}@media screen and (max-width: 767px){.purdue-home-intro-text.has-layout-two-line .section .container .columns:after{content:none}}.purdue-home-intro-text.has-layout-two-line .section .container .columns .column{flex-basis:40%;flex-grow:0}.purdue-home-intro-text.has-layout-two-line .section .container .purdue-home-subheader{text-align:left}.purdue-home-intro-text.has-layout-two-line .section.has-gold-background .container .columns:after{border-top:4px solid #000}.purdue-home-intro-text.has-layout-two-line .section.has-gold-background .tagged-header-container{border-color:#000}.purdue-home-intro-text .tagged-header-container{border-color:#cfb991;margin-bottom:2rem}.purdue-home-intro-text .purdue-home-intro-text__list{display:flex;list-style-type:none;margin-top:2rem;padding-left:0;flex-wrap:wrap}.purdue-home-intro-text .purdue-home-intro-text__list li:not(:last-child){margin-right:.5rem;padding-bottom:.5rem}@media screen and (max-width: 767px){.purdue-home-intro-text .purdue-home-intro-text__list li:not(:last-child){margin-right:0}}@media screen and (max-width: 767px){.purdue-home-intro-text .purdue-home-intro-text__list{flex-direction:column;margin-top:2rem}}
